"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = AppBar;
var _react = _interopRequireWildcard(require("react"));
var _styles = require("@mui/material/styles");
var _material = require("@mui/material");
var _propTypes = _interopRequireDefault(require("prop-types"));
var _clsx = _interopRequireDefault(require("clsx"));
var _pwacontext = _interopRequireDefault(require("./PWAContext"));
function _defineProperty(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
        return obj;
    } else {
        var newObj = {
        };
        if (obj != null) {
            for(var key in obj){
                if (Object.prototype.hasOwnProperty.call(obj, key)) {
                    var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {
                    };
                    if (desc.get || desc.set) {
                        Object.defineProperty(newObj, key, desc);
                    } else {
                        newObj[key] = obj[key];
                    }
                }
            }
        }
        newObj.default = obj;
        return newObj;
    }
}
function _objectSpread(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {
        };
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === "function") {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _defineProperty(target, key, source[key]);
        });
    }
    return target;
}
var PREFIX = 'AppBar';
var defaultClasses = {
    root: "".concat(PREFIX, "-root"),
    relative: "".concat(PREFIX, "-relative"),
    spacer: "".concat(PREFIX, "-spacer"),
    toolbar: "".concat(PREFIX, "-toolbar"),
    offline: "".concat(PREFIX, "-offline")
};
var _obj;
// TODO jss-to-styled codemod: The Fragment root was replaced by div. Change the tag if needed.
var Root = (0, _styles).styled('div')(function(param) {
    var theme = param.theme;
    return _obj = {
    }, /**
   * Styles applied to the root element.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.root), {
        boxSizing: 'border-box',
        backgroundColor: theme.palette.background.default,
        boxShadow: 'none',
        borderBottom: "1px solid ".concat(theme.palette.divider),
        zIndex: theme.zIndex.modal + 10,
        height: theme.headerHeight,
        display: 'flex',
        flexDirection: 'column',
        alignItems: 'stretch'
    }), _defineProperty(_obj, "& .".concat(defaultClasses.relative), {
        position: 'relative'
    }), /**
   * Styles applied to the spacer that fills the height behind the floating toolbar.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.spacer), {
        boxSizing: 'border-box',
        height: theme.headerHeight
    }), /**
   * Styles applied to the `Toolbar` element.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.toolbar), {
        justifyContent: 'space-between',
        alignItems: 'center',
        flex: 1
    }), /**
   * Styles applied to the offline warning element.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.offline), {
        textAlign: 'center',
        backgroundColor: '#f34c4c',
        zIndex: 999999,
        width: '100vw',
        color: 'white'
    }), _obj;
});
var _obj1;
function AppBar(param) {
    var children = param.children, tmp = param.classes, c = tmp === void 0 ? {
    } : tmp, style = param.style, variant = param.variant, fixed = param.fixed, offlineWarning = param.offlineWarning;
    if (fixed) {
        variant = 'fixed';
    }
    var classes = _objectSpread({
    }, defaultClasses, c);
    var trigger = (0, _material).useScrollTrigger();
    var offline = (0, _react).useContext(_pwacontext.default).offline;
    var appBar = /*#__PURE__*/ _react.default.createElement(_material.AppBar, {
        className: (0, _clsx).default((_obj1 = {
        }, _defineProperty(_obj1, classes.root, true), _defineProperty(_obj1, classes.relative, variant === 'relative'), _obj1)),
        style: _objectSpread({
        }, style)
    }, /*#__PURE__*/ _react.default.createElement(_material.Toolbar, {
        disableGutters: true,
        className: classes.toolbar
    }, children));
    if (variant === 'hide') {
        appBar = /*#__PURE__*/ _react.default.createElement(_material.Slide, {
            appear: false,
            in: !trigger
        }, appBar);
    }
    return(/*#__PURE__*/ _react.default.createElement(Root, null, (variant === 'hide' || variant === 'fixed') && /*#__PURE__*/ _react.default.createElement("div", {
        className: classes.spacer
    }), offline && /*#__PURE__*/ _react.default.createElement("div", {
        className: classes.offline
    }, offlineWarning), appBar));
}
AppBar.propTypes = {
    /**
   * Override or extend the styles applied to the component. See [CSS API](#css) below for more details.
   */ classes: _propTypes.default.object,
    /**
   * Affixes the AppBar to the top of the viewport. This prop is deprecated.
   * Use `variant="fixed"` instead.
   * @deprecated
   */ fixed: _propTypes.default.bool,
    /**
   * String or Element to render within the offline warning container at the top of the app.
   */ offlineWarning: _propTypes.default.oneOfType([
        _propTypes.default.string,
        _propTypes.default.element
    ]),
    /**
   * * relative - The AppBar stays at the top of the page.
   * * fixed - The AppBar stays at the top of the viewport.
   * * hide - The same as fixed, but the app bar automatically hides when the user scrolls down.
   */ variant: _propTypes.default.oneOf([
        'relative',
        'fixed',
        'hide'
    ]),
    style: _propTypes.default.object,
    children: _propTypes.default.any
};
AppBar.defaultProps = {
    offlineWarning: 'Your device lost its internet connection.',
    variant: 'hide',
    fixed: false,
    style: {
    }
};

//# sourceMappingURL=AppBar.js.map