"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = Breadcrumbs;
var _react = _interopRequireDefault(require("react"));
var _styles = require("@mui/material/styles");
var _iconsMaterial = require("@mui/icons-material");
var _clsx = _interopRequireDefault(require("clsx"));
var _material = require("@mui/material");
var _propTypes = _interopRequireDefault(require("prop-types"));
var _link = _interopRequireDefault(require("./link/Link"));
function _defineProperty(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
function _objectSpread(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {
        };
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === "function") {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _defineProperty(target, key, source[key]);
        });
    }
    return target;
}
var PREFIX = 'Breadcrumbs';
var defaultClasses = {
    breadcrumbs: "".concat(PREFIX, "-breadcrumbs"),
    separator: "".concat(PREFIX, "-separator"),
    current: "".concat(PREFIX, "-current")
};
var _obj;
var StyledTypography = (0, _styles).styled(_material.Typography)(function(param) {
    var theme = param.theme;
    return _obj = {
    }, /**
   * Styles applied to the root element.
   */ _defineProperty(_obj, "&.".concat(defaultClasses.breadcrumbs), {
        backgroundColor: '#F4F2F1',
        padding: '12px 0',
        '& a': {
            color: theme.palette.text.primary,
            textDecoration: 'none'
        }
    }), /**
   * Styles applied to the separators.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.separator), {
        height: '12px',
        position: 'relative',
        top: '2px',
        width: '16px'
    }), /**
   * Styles applied to the currently active breadcrumb's element.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.current), {
        fontWeight: 'bold',
        color: theme.palette.text.primary
    }), _obj;
});
function Breadcrumbs(param) {
    var items = param.items, tmp = param.classes, c = tmp === void 0 ? {
    } : tmp;
    var classes = _objectSpread({
    }, defaultClasses, c);
    return(/*#__PURE__*/ _react.default.createElement(StyledTypography, {
        display: "block",
        className: classes.breadcrumbs,
        variant: "caption"
    }, /*#__PURE__*/ _react.default.createElement(_material.Container, null, items && items.map(function(item, i) {
        var arrow = i > 0 ? /*#__PURE__*/ _react.default.createElement(_iconsMaterial.KeyboardArrowRight, {
            className: classes.separator
        }) : null;
        var isLastItem = items.length - 1 === i;
        if (item.href) {
            return(/*#__PURE__*/ _react.default.createElement("span", {
                key: i,
                className: (0, _clsx).default(isLastItem && classes.current)
            }, arrow, /*#__PURE__*/ _react.default.createElement(_link.default, {
                href: item.href,
                as: item.as
            }, item.text)));
        }
        return(/*#__PURE__*/ _react.default.createElement("span", {
            key: i,
            className: (0, _clsx).default(isLastItem && classes.current)
        }, arrow, item.text));
    }), /*#__PURE__*/ _react.default.createElement("span", null, "\xa0"))));
}
Breadcrumbs.propTypes = {
    /**
   * Override or extend the styles applied to the component. See [CSS API](#css) below for more details.
   */ classes: _propTypes.default.object,
    /**
   * The items to display, each with text, [`href`](/apiReference/link/Link#prop-href), and
   * [`as`](/apiReference/link/Link#props-as) values. If `false`, no breadcrumbs will be displayed.
   */ items: _propTypes.default.oneOfType([
        _propTypes.default.arrayOf(_propTypes.default.shape({
            text: _propTypes.default.string,
            as: _propTypes.default.string,
            href: _propTypes.default.string
        })),
        _propTypes.default.bool, 
    ])
};

//# sourceMappingURL=Breadcrumbs.js.map