"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = ExpandableSection;
var _react = _interopRequireDefault(require("react"));
var _styles = require("@mui/material/styles");
var _propTypes = _interopRequireDefault(require("prop-types"));
var _clsx = _interopRequireDefault(require("clsx"));
var _material = require("@mui/material");
var _iconsMaterial = require("@mui/icons-material");
var _useStateFromProp = _interopRequireDefault(require("./hooks/useStateFromProp"));
var _withDefaultHandler = _interopRequireDefault(require("./utils/withDefaultHandler"));
function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
}
function _defineProperty(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _extends() {
    _extends = Object.assign || function(target) {
        for(var i = 1; i < arguments.length; i++){
            var source = arguments[i];
            for(var key in source){
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key];
                }
            }
        }
        return target;
    };
    return _extends.apply(this, arguments);
}
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
function _iterableToArrayLimit(arr, i) {
    var _arr = [];
    var _n = true;
    var _d = false;
    var _e = undefined;
    try {
        for(var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true){
            _arr.push(_s.value);
            if (i && _arr.length === i) break;
        }
    } catch (err) {
        _d = true;
        _e = err;
    } finally{
        try {
            if (!_n && _i["return"] != null) _i["return"]();
        } finally{
            if (_d) throw _e;
        }
    }
    return _arr;
}
function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
}
function _objectSpread(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {
        };
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === "function") {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _defineProperty(target, key, source[key]);
        });
    }
    return target;
}
function _objectWithoutProperties(source, excluded) {
    if (source == null) return {
    };
    var target = _objectWithoutPropertiesLoose(source, excluded);
    var key, i;
    if (Object.getOwnPropertySymbols) {
        var sourceSymbolKeys = Object.getOwnPropertySymbols(source);
        for(i = 0; i < sourceSymbolKeys.length; i++){
            key = sourceSymbolKeys[i];
            if (excluded.indexOf(key) >= 0) continue;
            if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
            target[key] = source[key];
        }
    }
    return target;
}
function _objectWithoutPropertiesLoose(source, excluded) {
    if (source == null) return {
    };
    var target = {
    };
    var sourceKeys = Object.keys(source);
    var key, i;
    for(i = 0; i < sourceKeys.length; i++){
        key = sourceKeys[i];
        if (excluded.indexOf(key) >= 0) continue;
        target[key] = source[key];
    }
    return target;
}
function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
}
var PREFIX = 'RSFExpandableSection';
var defaultClasses = {
    root: "".concat(PREFIX, "-root"),
    margins: "".concat(PREFIX, "-margins"),
    caption: "".concat(PREFIX, "-caption"),
    expandedCaption: "".concat(PREFIX, "-expandedCaption"),
    details: "".concat(PREFIX, "-details"),
    summary: "".concat(PREFIX, "-summary"),
    summaryContent: "".concat(PREFIX, "-summaryContent"),
    summaryExpanded: "".concat(PREFIX, "-summaryExpanded"),
    expandIconExpanded: "".concat(PREFIX, "-expandIconExpanded"),
    summaryIconWrap: "".concat(PREFIX, "-summaryIconWrap"),
    withCollapseIcon: "".concat(PREFIX, "-withCollapseIcon"),
    expandedPanel: "".concat(PREFIX, "-expandedPanel"),
    title: "".concat(PREFIX, "-title"),
    expandIcon: "".concat(PREFIX, "-expandIcon"),
    collapseIcon: "".concat(PREFIX, "-collapseIcon")
};
var _obj;
var StyledAccordion = (0, _styles).styled(_material.Accordion)(function(param) {
    var theme = param.theme;
    return _obj = {
    }, /**
   * Styles applied to the root element.
   */ _defineProperty(_obj, "&.".concat(defaultClasses.root), {
        boxShadow: 'none',
        borderBottom: "1px solid ".concat(theme.palette.divider),
        background: 'transparent',
        '&::before': {
            display: 'none'
        },
        '& > *:first-child': {
            padding: '0',
            minHeight: '0'
        }
    }), /**
   * Styles applied to the root element if [`margins`](#prop-margins) is `true`.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.margins), {
        padding: "0 ".concat(theme.spacing(2))
    }), /**
   * Styles applied to the caption element.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.caption), {
        transition: 'opacity .2s linear'
    }), /**
   * Styles applied to the caption element when the section is expanded.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.expandedCaption), {
        opacity: 0
    }), /**
   * Styles applied to the body element of the expansion panel.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.details), {
        padding: theme.spacing(0, 0, 2, 0),
        display: 'flex',
        flexDirection: 'column'
    }), /**
   * Styles applied to the summary element of the expansion panel.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.summary), {
        '&:first-child': {
            padding: theme.spacing(1, 0)
        }
    }), /**
   * Styles applied to the content of the summary element of the expansion panel.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.summaryContent), {
        display: 'flex',
        justifyContent: 'space-between',
        alignItems: 'center',
        margin: 0,
        '[aria-expanded=true] > &': {
            margin: '0 !important'
        }
    }), /**
   * Styles applied to the summary element of the expansion panel when the section is expanded.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.summaryExpanded), {
    }), /**
   * Styles applied to the expand icon of the expansion panel when the section is expanded if the
   * [`ExpandIcon`](#prop-ExpandIcon) is different than the [`CollapseIcon`](#prop-CollapseIcon).
   */ _defineProperty(_obj, "& .".concat(defaultClasses.expandIconExpanded), {
    }), /**
   * Styles applied to the expand icon of the expansion panel when the [`ExpandIcon`](#prop-ExpandIcon)
   * is different than the [`CollapseIcon`](#prop-CollapseIcon).
   */ _defineProperty(_obj, "& .".concat(defaultClasses.summaryIconWrap), {
        right: 0,
        padding: theme.spacing(0, 1)
    }), /**
   * Styles applied to the summary element of the expansion panel.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.withCollapseIcon), {
        transform: 'rotate(0deg) !important'
    }), /**
   * Styles applied to the root element when the section is expanded.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.expandedPanel), {
        '&$root': {
            margin: 0
        }
    }), /**
   * Styles applied to the title element.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.title), {
    }), /**
   * Styles applied to the expand icon element.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.expandIcon), {
        height: 24,
        width: 24
    }), /**
   * Styles applied to the collapse icon element.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.collapseIcon), {
        height: 24,
        width: 24
    }), _obj;
});
var _obj1, _obj2, _obj3, _obj4;
function ExpandableSection(props) {
    var getSummaryClasses = /**
   * Gets the classes for the AccordionSummary
   * Here we add a class to remove the rotate transform if we're using a
   * separate icon for the collapse state.
   */ function getSummaryClasses() {
        var result = {
            root: (0, _clsx).default((_obj1 = {
            }, _defineProperty(_obj1, classes.summary, true), _defineProperty(_obj1, classes.summaryExpanded, expandedState), _obj1)),
            content: classes.summaryContent,
            expandIcon: (0, _clsx).default((_obj2 = {
            }, _defineProperty(_obj2, classes.summaryIconWrap, true), _defineProperty(_obj2, classes.expandIconExpanded, expandedState), _obj2))
        };
        if (CollapseIcon !== ExpandIcon) {
            result.expandIcon = classes.withCollapseIcon;
        }
        return result;
    };
    var tmp = props.classes, c = tmp === void 0 ? {
    } : tmp, _children = props.children, children = _children === void 0 ? [] : _children, title = props.title, caption = props.caption, expanded1 = props.expanded, defaultExpanded = props.defaultExpanded, ExpandIcon = props.ExpandIcon, CollapseIcon = props.CollapseIcon, margins = props.margins, onChange = props.onChange, others = _objectWithoutProperties(props, [
        "classes",
        "children",
        "title",
        "caption",
        "expanded",
        "defaultExpanded",
        "ExpandIcon",
        "CollapseIcon",
        "margins",
        "onChange"
    ]);
    var classes = _objectSpread({
    }, defaultClasses, c);
    var ref = _slicedToArray((0, _useStateFromProp).default(expanded1 || defaultExpanded || false), 2), expandedState = ref[0], setExpandedState = ref[1];
    var handleChange = (0, _withDefaultHandler).default(onChange, function(e, expanded) {
        if (props.expanded == null) {
            setExpandedState(expanded);
        }
    });
    return(/*#__PURE__*/ _react.default.createElement(StyledAccordion, _extends({
        classes: {
            root: (0, _clsx).default((_obj3 = {
            }, _defineProperty(_obj3, classes.root, true), _defineProperty(_obj3, classes.margins, margins), _obj3)),
            expanded: classes.expandedPanel
        },
        expanded: expandedState,
        defaultExpanded: defaultExpanded
    }, others, {
        onChange: handleChange
    }), /*#__PURE__*/ _react.default.createElement(_material.AccordionSummary, {
        expandIcon: expandedState ? /*#__PURE__*/ _react.default.createElement(CollapseIcon, {
            className: classes.collapseIcon
        }) : /*#__PURE__*/ _react.default.createElement(ExpandIcon, {
            className: classes.expandIcon
        }),
        classes: getSummaryClasses()
    }, /*#__PURE__*/ _react.default.createElement(_material.Typography, {
        variant: "subtitle1",
        className: classes.title
    }, title), caption && /*#__PURE__*/ _react.default.createElement(_material.Typography, {
        variant: "caption",
        className: (0, _clsx).default((_obj4 = {
        }, _defineProperty(_obj4, classes.caption, true), _defineProperty(_obj4, classes.expandedCaption, expandedState), _obj4))
    }, caption)), /*#__PURE__*/ _react.default.createElement(_material.AccordionDetails, {
        classes: {
            root: classes.details
        }
    }, children)));
}
ExpandableSection.propTypes = {
    /**
   * The title for the header of the expandable section.
   */ title: _propTypes.default.oneOfType([
        _propTypes.default.string,
        _propTypes.default.element
    ]),
    /**
   * Text to display to the right of the heading.
   */ caption: _propTypes.default.oneOfType([
        _propTypes.default.string,
        _propTypes.default.element
    ]),
    /**
   * The icon to use for collapsed groups.
   */ ExpandIcon: _propTypes.default.elementType,
    /**
   * The icon to use for expanded groups.
   */ CollapseIcon: _propTypes.default.elementType,
    /**
   * If `false`, the default left and right margins are removed.
   */ margins: _propTypes.default.bool,
    /**
   * Can be defined to control the expanded state externally with props, rather than having it
   * controlled internally by state.
   */ expanded: _propTypes.default.bool,
    /**
   * Defaults the panel to being expanded, without controlling the state.
   */ defaultExpanded: _propTypes.default.bool,
    classes: _propTypes.default.object,
    onChange: _propTypes.default.func
};
ExpandableSection.defaultProps = {
    margins: true,
    defaultExpanded: false,
    ExpandIcon: _iconsMaterial.ExpandMore,
    CollapseIcon: _iconsMaterial.ExpandMore
};

//# sourceMappingURL=ExpandableSection.js.map