"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = LoadMask;
var _react = _interopRequireWildcard(require("react"));
var _styles = require("@mui/material/styles");
var _clsx = _interopRequireDefault(require("clsx"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _material = require("@mui/material");
function _defineProperty(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
        return obj;
    } else {
        var newObj = {
        };
        if (obj != null) {
            for(var key in obj){
                if (Object.prototype.hasOwnProperty.call(obj, key)) {
                    var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {
                    };
                    if (desc.get || desc.set) {
                        Object.defineProperty(newObj, key, desc);
                    } else {
                        newObj[key] = obj[key];
                    }
                }
            }
        }
        newObj.default = obj;
        return newObj;
    }
}
function _objectSpread(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {
        };
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === "function") {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _defineProperty(target, key, source[key]);
        });
    }
    return target;
}
var PREFIX = 'RSFLoadMask';
var defaultClasses = {
    root: "".concat(PREFIX, "-root"),
    fullscreen: "".concat(PREFIX, "-fullscreen"),
    transparent: "".concat(PREFIX, "-transparent"),
    alignTop: "".concat(PREFIX, "-alignTop"),
    show: "".concat(PREFIX, "-show")
};
var _obj;
var Root = (0, _styles).styled('div')(function(param) {
    var theme = param.theme;
    return _obj = {
    }, /**
   * Styles applied to the root element.
   */ _defineProperty(_obj, "&.".concat(defaultClasses.root), {
        position: 'absolute',
        top: 0,
        left: 0,
        height: '100%',
        width: '100%',
        display: 'none',
        justifyContent: 'center',
        alignItems: 'center',
        background: theme.palette.background.default,
        zIndex: 1
    }), /**
   * Styles applied to the root element when [`fullscreen`](#prop-fullscreen) is `true`.
   */ _defineProperty(_obj, "&.".concat(defaultClasses.fullscreen), {
        height: "calc(100vh - ".concat(theme.loadMaskOffsetTop, "px)"),
        bottom: 'initial',
        zIndex: theme.zIndex.modal - 20,
        'body.moov-amp &': {
            position: 'fixed',
            marginTop: 0,
            opacity: 0.8
        }
    }), /**
   * Styles applied to the root element when [`transparent`](#prop-transparent) is `true`.
   */ _defineProperty(_obj, "&.".concat(defaultClasses.transparent), {
        backgroundColor: 'rgba(255,255,255,0.5)'
    }), /**
   * Styles applied to the root element when [`align`](#prop-align) is `'top'`.
   */ _defineProperty(_obj, "&.".concat(defaultClasses.alignTop), {
        alignItems: 'flex-start',
        paddingTop: '200px'
    }), /**
   * Styles applied to the root element when [`show`](#prop-show) is `true`.
   */ _defineProperty(_obj, "&.".concat(defaultClasses.show), {
        display: 'flex'
    }), _obj;
});
var _obj1;
function LoadMask(param) {
    var show = param.show, style = param.style, className = param.className, tmp = param.classes, c = tmp === void 0 ? {
    } : tmp, children = param.children, fullscreen = param.fullscreen, transparent = param.transparent, align = param.align;
    var classes = _objectSpread({
    }, defaultClasses, c);
    (0, _react).useEffect(function() {
        if (fullscreen) {
            document.body.style.overflow = show ? 'hidden' : 'visible';
        }
    }, [
        show,
        fullscreen
    ]);
    (0, _react).useEffect(function() {
        return function() {
            if (fullscreen) {
                document.body.style.overflow = 'visible';
            }
        };
    });
    return(/*#__PURE__*/ _react.default.createElement(Root, {
        style: style,
        className: (0, _clsx).default(className, classes.root, (_obj1 = {
        }, _defineProperty(_obj1, classes.show, show !== false), _defineProperty(_obj1, classes.fullscreen, fullscreen), _defineProperty(_obj1, classes.transparent, transparent), _defineProperty(_obj1, classes.alignTop, align === 'top'), _obj1))
    }, children || /*#__PURE__*/ _react.default.createElement(_material.CircularProgress, {
        className: classes.progress,
        color: "secondary"
    })));
}
LoadMask.propTypes = {
    /**
   * Override or extend the styles applied to the component. See [CSS API](#css) below for more details.
   */ classes: _propTypes.default.object,
    /**
   * If defined, `true` will display the load mask, while `false` will be hide it.
   */ show: _propTypes.default.bool,
    /**
   * Set to `true` to toggle the overflow style on the body when showing.
   */ fullscreen: _propTypes.default.bool,
    /**
   * Set to `true` to show partially background through the load mask
   */ transparent: _propTypes.default.bool,
    /**
   * Set to `'top'` to show the spinner near the top.
   */ align: _propTypes.default.oneOf([
        'center',
        'top'
    ]),
    style: _propTypes.default.object,
    className: _propTypes.default.string
};
LoadMask.defaultProps = {
    fullscreen: false,
    transparent: false,
    align: 'center'
};

//# sourceMappingURL=LoadMask.js.map