"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = PWA;
var _react = _interopRequireWildcard(require("react"));
var _styles = require("@mui/material/styles");
var _propTypes = _interopRequireDefault(require("prop-types"));
var _pwacontext = _interopRequireDefault(require("./PWAContext"));
var _errorBoundary = _interopRequireDefault(require("./ErrorBoundary"));
var _linkContextProvider = _interopRequireDefault(require("./link/LinkContextProvider"));
var _useSimpleNavigation = _interopRequireDefault(require("./router/useSimpleNavigation"));
require("./hooks/useTraceUpdate");
require("./profile");
function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
}
function _defineProperty(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
        return obj;
    } else {
        var newObj = {
        };
        if (obj != null) {
            for(var key in obj){
                if (Object.prototype.hasOwnProperty.call(obj, key)) {
                    var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {
                    };
                    if (desc.get || desc.set) {
                        Object.defineProperty(newObj, key, desc);
                    } else {
                        newObj[key] = obj[key];
                    }
                }
            }
        }
        newObj.default = obj;
        return newObj;
    }
}
function _iterableToArrayLimit(arr, i) {
    var _arr = [];
    var _n = true;
    var _d = false;
    var _e = undefined;
    try {
        for(var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true){
            _arr.push(_s.value);
            if (i && _arr.length === i) break;
        }
    } catch (err) {
        _d = true;
        _e = err;
    } finally{
        try {
            if (!_n && _i["return"] != null) _i["return"]();
        } finally{
            if (_d) throw _e;
        }
    }
    return _arr;
}
function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
}
function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
}
var PREFIX = 'RSFPWA';
var classes = {
    body: "".concat(PREFIX, "-body"),
    a: "".concat(PREFIX, "-a")
};
var _obj;
var StyledPWAContextProvider = (0, _styles).styled(_pwacontext.default.Provider)(function(param) {
    var theme = param.theme;
    return _obj = {
    }, _defineProperty(_obj, "& .".concat(classes.body), {
        'WebkitTapHighlightColor?': 'transparent'
    }), _defineProperty(_obj, "& .".concat(classes.a), {
        color: theme.palette.primary.main,
        textDecoration: 'underline'
    }), _obj;
});
function PWA(param) {
    var children = param.children, errorReporter = param.errorReporter;
    var thumbnail = (0, _react).useRef(null);
    var ref = _slicedToArray((0, _react).useState(typeof navigator !== 'undefined' && !navigator.onLine), 2), offline = ref[0], setOffline = ref[1];
    var context = (0, _react).useMemo(function() {
        return {
            thumbnail: thumbnail,
            offline: offline
        };
    }, [
        offline
    ]);
    // enable client-side navigation when the user clicks a simple HTML anchor element
    (0, _useSimpleNavigation).default();
    (0, _react).useEffect(function() {
        context.hydrating = false;
        var handleOnline = function() {
            return setOffline(false);
        };
        var handleOffline = function() {
            return setOffline(true);
        };
        window.addEventListener('online', handleOnline);
        window.addEventListener('offline', handleOffline);
        return function() {
            window.removeEventListener('online', handleOnline);
            window.removeEventListener('offline', handleOffline);
        };
    }, []);
    return(/*#__PURE__*/ _react.default.createElement(StyledPWAContextProvider, {
        value: context
    }, /*#__PURE__*/ _react.default.createElement(_linkContextProvider.default, null, /*#__PURE__*/ _react.default.createElement(_errorBoundary.default, {
        onError: errorReporter
    }, children))));
}
PWA.propTypes = {
    /**
   * A function to be called whenever an error occurs.  Use this to report errors
   * to a service like Airbrake or Rollbar.
   */ errorReporter: _propTypes.default.func
};

//# sourceMappingURL=PWA.js.map