"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = Rating;
var _react = _interopRequireDefault(require("react"));
var _styles = require("@mui/material/styles");
var _iconsMaterial = require("@mui/icons-material");
var _propTypes = _interopRequireDefault(require("prop-types"));
var _clsx = _interopRequireDefault(require("clsx"));
var _box = require("./Box");
function _defineProperty(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
function _objectSpread(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {
        };
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === "function") {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _defineProperty(target, key, source[key]);
        });
    }
    return target;
}
var PREFIX = 'RSFRating';
var defaultClasses = {
    root: "".concat(PREFIX, "-root"),
    filledEmpty: "".concat(PREFIX, "-filledEmpty"),
    blank: "".concat(PREFIX, "-blank"),
    reviewsLabel: "".concat(PREFIX, "-reviewsLabel")
};
var _obj;
var Root = (0, _styles).styled('span')(function(param) {
    var theme = param.theme;
    return _obj = {
    }, /**
   * Styles applied to the root element.
   */ _defineProperty(_obj, "&.".concat(defaultClasses.root), {
        display: 'flex',
        '& svg': {
            color: theme.palette.rating,
            height: '16px',
            width: '16px',
            display: 'block'
        }
    }), /**
   * Styles applied to an empty rating icon.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.filledEmpty), {
        fill: theme.palette.divider
    }), /**
   * Styles applied to the root element when [`value`](#prop-value) is `0`.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.blank), {
        '& svg': {
            color: theme.palette.divider
        }
    }), /**
   * Styles applied to the label element.
   */ _defineProperty(_obj, "&.".concat(defaultClasses.reviewsLabel), {
        marginLeft: '3px'
    }), _obj;
});
function Rating(param) {
    var iconFull = param.iconFull, iconHalf = param.iconHalf, iconEmpty = param.iconEmpty, tmp = param.classes, c = tmp === void 0 ? {
    } : tmp, value = param.value, label = param.label, reviewCount = param.reviewCount, className = param.className, product = param.product, fillEmpty = param.fillEmpty;
    var classes = _objectSpread({
    }, defaultClasses, c);
    var stars = [];
    if (product) {
        reviewCount = product.reviewCount;
        value = product.rating;
    }
    var IconFull = iconFull || _iconsMaterial.Star;
    var IconHalf = iconHalf || _iconsMaterial.StarHalf;
    var IconEmpty = iconEmpty || _iconsMaterial.StarBorder;
    for(var i = 1; i <= 5; i++){
        if (value == null || value >= i) {
            stars.push(/*#__PURE__*/ _react.default.createElement(IconFull, {
                key: i
            }));
        } else if (value >= i - 0.5) {
            stars.push(/*#__PURE__*/ _react.default.createElement(IconHalf, {
                key: i
            }));
        } else if (fillEmpty) {
            stars.push(/*#__PURE__*/ _react.default.createElement(IconFull, {
                className: classes.filledEmpty,
                key: i
            }));
        } else {
            stars.push(/*#__PURE__*/ _react.default.createElement(IconEmpty, {
                key: i
            }));
        }
    }
    return(/*#__PURE__*/ _react.default.createElement(_box.Hbox, null, /*#__PURE__*/ _react.default.createElement(Root, {
        className: (0, _clsx).default(classes.root, className, _defineProperty({
        }, classes.blank, value == null))
    }, stars), reviewCount ? /*#__PURE__*/ _react.default.createElement(Root, {
        className: classes.reviewsLabel
    }, "(", reviewCount, label(reviewCount), ")") : null));
}
Rating.propTypes = {
    /**
   * Override or extend the styles applied to the component. See [CSS API](#css) below for more details.
   */ classes: _propTypes.default.object,
    /**
   * The number of stars to display.  Can be an integer or a float ending in .5.
   */ value: _propTypes.default.number,
    /**
   * The number of reviews.
   */ reviewCount: _propTypes.default.number,
    /**
   * A function that returns the label displayed to the right of the review count.
   * For example: `<Rating label={reviewCount => <span> {reviewCount == 1 ? 'review' : 'reviews'}</span>}/>`.
   * This value used in this example is the default.
   */ label: _propTypes.default.func,
    /**
   * Can be used to as an alternative to setting `value` and `reviewCount` individually.
   */ product: _propTypes.default.object,
    /**
   * Custom full point icon.
   */ iconFull: _propTypes.default.elementType,
    /**
   * Custom half point icon.
   */ iconHalf: _propTypes.default.elementType,
    /**
   * Custom empty icon; will override `fillEmpty` icon.
   */ iconEmpty: _propTypes.default.elementType,
    /**
   * If `true`, use a filled icon with light gray background for empty icon
   */ fillEmpty: _propTypes.default.bool,
    className: _propTypes.default.string
};
Rating.defaultProps = {
    label: function(reviewCount) {
        /*#__PURE__*/ return _react.default.createElement("span", null, " ", reviewCount == 1 ? 'review' : 'reviews');
    },
    fillEmpty: false
};

//# sourceMappingURL=Rating.js.map