"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = ResponsiveTiles;
var _react = _interopRequireWildcard(require("react"));
var _styles = require("@mui/material/styles");
var _material = require("@mui/material");
var _clsx = _interopRequireDefault(require("clsx"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _autoScrollToNewChildren = _interopRequireDefault(require("./AutoScrollToNewChildren"));
function _defineProperty(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _extends() {
    _extends = Object.assign || function(target) {
        for(var i = 1; i < arguments.length; i++){
            var source = arguments[i];
            for(var key in source){
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key];
                }
            }
        }
        return target;
    };
    return _extends.apply(this, arguments);
}
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
        return obj;
    } else {
        var newObj = {
        };
        if (obj != null) {
            for(var key in obj){
                if (Object.prototype.hasOwnProperty.call(obj, key)) {
                    var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {
                    };
                    if (desc.get || desc.set) {
                        Object.defineProperty(newObj, key, desc);
                    } else {
                        newObj[key] = obj[key];
                    }
                }
            }
        }
        newObj.default = obj;
        return newObj;
    }
}
function _objectSpread(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {
        };
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === "function") {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _defineProperty(target, key, source[key]);
        });
    }
    return target;
}
function _objectWithoutProperties(source, excluded) {
    if (source == null) return {
    };
    var target = _objectWithoutPropertiesLoose(source, excluded);
    var key, i;
    if (Object.getOwnPropertySymbols) {
        var sourceSymbolKeys = Object.getOwnPropertySymbols(source);
        for(i = 0; i < sourceSymbolKeys.length; i++){
            key = sourceSymbolKeys[i];
            if (excluded.indexOf(key) >= 0) continue;
            if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
            target[key] = source[key];
        }
    }
    return target;
}
function _objectWithoutPropertiesLoose(source, excluded) {
    if (source == null) return {
    };
    var target = {
    };
    var sourceKeys = Object.keys(source);
    var key, i;
    for(i = 0; i < sourceKeys.length; i++){
        key = sourceKeys[i];
        if (excluded.indexOf(key) >= 0) continue;
        target[key] = source[key];
    }
    return target;
}
function ResponsiveTiles(props) {
    var Tiles = (0, _react).useRef(createTiles(props));
    var cols = props.cols, spacing = props.spacing, others = _objectWithoutProperties(props, [
        "cols",
        "spacing"
    ]);
    return(/*#__PURE__*/ _react.default.createElement(Tiles.current, _extends({
    }, others)));
}
ResponsiveTiles.propTypes = {
    /**
   * If `true`, automatically scroll to the first new tile when the
   * number of tiles is increased.
   */ autoScrollToNewTiles: _propTypes.default.bool,
    /**
   * A map of viewport widths to number of columns.  For example:
   * ```
   *  cols={{
   *    xs: 2,
   *    sm: 3,
   *    md: 4,
   *    lg: 5,
   *    xl: 5
   *  }}
   * ```
   */ cols: _propTypes.default.shape({
        xs: _propTypes.default.number,
        sm: _propTypes.default.number,
        md: _propTypes.default.number,
        lg: _propTypes.default.number,
        xl: _propTypes.default.number
    }),
    /**
   * The spacing between the tiles in theme spacing units.
   */ spacing: _propTypes.default.number
};
ResponsiveTiles.defaultProps = {
    autoScrollToNewTiles: false,
    cols: {
        xs: 2,
        sm: 3,
        md: 4,
        lg: 5,
        xl: 5
    },
    spacing: 1
};
var _obj;
function createTiles(param1) {
    var cols = param1.cols, spacing = param1.spacing;
    var maybeWrapInAutoScroll = function maybeWrapInAutoScroll(doWrap) {
        return function(elements) {
            if (doWrap) {
                return(/*#__PURE__*/ _react.default.createElement(_autoScrollToNewChildren.default, null, elements));
            }
            return elements;
        };
    };
    var PREFIX = 'ResponsiveTiles';
    var classes = {
        root: "".concat(PREFIX, "-root"),
        tile: "".concat(PREFIX, "-tile")
    };
    var Root = (0, _styles).styled('ul')(function(param2) {
        var theme = param2.theme;
        var breakpoints = {
        };
        // Breakpoints MUST be set in order from smallest to largest
        Object.keys(cols).map(function(width) {
            return {
                key: width,
                value: cols[width],
                width: "".concat(100 / cols[width], "%")
            };
        }).sort(function(a, b) {
            return a.value - b.value;
        }).forEach(function(param) {
            var key = param.key, width = param.width;
            breakpoints[theme.breakpoints.up(key)] = {
                width: width
            };
        });
        return _obj = {
        }, _defineProperty(_obj, "&.".concat(classes.root), {
            display: 'flex',
            flexWrap: 'wrap',
            overflowY: 'auto',
            listStyle: 'none',
            padding: 0,
            margin: theme.spacing(-spacing),
            WebkitOverflowScrolling: 'touch'
        }), _defineProperty(_obj, "& .".concat(classes.tile), _objectSpread({
        }, breakpoints, {
            padding: theme.spacing(spacing),
            height: 'auto'
        })), _obj;
    });
    var Tiles = function Tiles(_param) {
        var className = _param.className, autoScrollToNewTiles = _param.autoScrollToNewTiles, children = _param.children, other = _objectWithoutProperties(_param, [
            "className",
            "autoScrollToNewTiles",
            "children"
        ]);
        return(/*#__PURE__*/ _react.default.createElement(Root, _extends({
            className: (0, _clsx).default(className, classes.root)
        }, other), maybeWrapInAutoScroll(autoScrollToNewTiles)(_react.default.Children.map(children, function(child, i) {
            if (!/*#__PURE__*/ _react.default.isValidElement(child)) {
                return null;
            }
            return(/*#__PURE__*/ _react.default.createElement(_material.ImageListItem, {
                key: i,
                classes: {
                    root: classes.tile
                }
            }, child));
        }))));
    };
    Tiles.propTypes = {
        className: _propTypes.default.string,
        autoScrollToNewTiles: _propTypes.default.bool
    };
    return Tiles;
}

//# sourceMappingURL=ResponsiveTiles.js.map