"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = CarouselArrows;
var _propTypes = _interopRequireDefault(require("prop-types"));
var _styles = require("@mui/material/styles");
var _react = _interopRequireWildcard(require("react"));
var _clsx = _interopRequireDefault(require("clsx"));
var _material = require("@mui/material");
var _iconsMaterial = require("@mui/icons-material");
function _defineProperty(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
        return obj;
    } else {
        var newObj = {
        };
        if (obj != null) {
            for(var key in obj){
                if (Object.prototype.hasOwnProperty.call(obj, key)) {
                    var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {
                    };
                    if (desc.get || desc.set) {
                        Object.defineProperty(newObj, key, desc);
                    } else {
                        newObj[key] = obj[key];
                    }
                }
            }
        }
        newObj.default = obj;
        return newObj;
    }
}
function _objectSpread(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {
        };
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === "function") {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _defineProperty(target, key, source[key]);
        });
    }
    return target;
}
var PREFIX = 'RSFCarouselArrows';
var defaultClasses = {
    arrows: "".concat(PREFIX, "-arrows"),
    arrow: "".concat(PREFIX, "-arrow"),
    leftArrow: "".concat(PREFIX, "-leftArrow"),
    rightArrow: "".concat(PREFIX, "-rightArrow"),
    icon: "".concat(PREFIX, "-icon")
};
var _obj;
var Root = (0, _styles).styled('div')(function() {
    return _obj = {
    }, /**
   * Styles applied to the root element.
   */ _defineProperty(_obj, "&.".concat(defaultClasses.arrows), {
    }), /**
   * Styles applied to each of the arrow icon buttons.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.arrow), {
        position: 'absolute',
        top: '50%',
        marginTop: '-24px'
    }), /**
   * Styles applied to the left arrow icon buttons.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.leftArrow), {
        left: 0
    }), /**
   * Styles applied to the right arrow icon buttons.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.rightArrow), {
        right: 0
    }), /**
   * Styles applied to each of the icon elements.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.icon), {
    }), _obj;
});
function CarouselArrows(param) {
    var className = param.className, tmp = param.classes, c = tmp === void 0 ? {
    } : tmp, selected = param.selected, count = param.count, setSelected = param.setSelected, infinite = param.infinite, leftArrowLabel = param.leftArrowLabel, rightArrowLabel = param.rightArrowLabel;
    var classes = _objectSpread({
    }, defaultClasses, c);
    var createOnClickArrow = (0, _react).useCallback(function(idxChange) {
        return function(evt) {
            evt.preventDefault();
            if (!infinite) {
                setSelected(selected + idxChange);
                return;
            }
            // carousel loop-around calculations
            var nextSelectedIndex = selected + idxChange;
            if (nextSelectedIndex + 1 > count) {
                nextSelectedIndex = 0;
            } else if (nextSelectedIndex < 0) {
                nextSelectedIndex = count - 1;
            }
            setSelected(nextSelectedIndex);
        };
    }, [
        selected,
        setSelected,
        count,
        infinite
    ]);
    return(/*#__PURE__*/ _react.default.createElement(Root, {
        className: (0, _clsx).default(classes.arrows, className)
    }, (selected !== 0 || infinite) && /*#__PURE__*/ _react.default.createElement(_material.IconButton, {
        className: (0, _clsx).default(classes.arrow, classes.leftArrow),
        onClick: createOnClickArrow(-1),
        "aria-label": leftArrowLabel,
        size: "large"
    }, /*#__PURE__*/ _react.default.createElement(_iconsMaterial.ChevronLeft, {
        classes: {
            root: classes.icon
        }
    })), (selected !== count - 1 || infinite) && /*#__PURE__*/ _react.default.createElement(_material.IconButton, {
        className: (0, _clsx).default(classes.arrow, classes.rightArrow),
        onClick: createOnClickArrow(1),
        "aria-label": rightArrowLabel,
        size: "large"
    }, /*#__PURE__*/ _react.default.createElement(_iconsMaterial.ChevronRight, {
        classes: {
            root: classes.icon
        }
    }))));
}
CarouselArrows.propTypes = {
    /**
   * Override or extend the styles applied to the component. See [CSS API](#css) below for more details.
   */ classes: _propTypes.default.object,
    /**
   * CSS class to apply to the root element.
   */ className: _propTypes.default.string,
    /**
   * Index of the currently selected slide in the [`Carousel`](/apiReference/carousel/Carousel).
   */ selected: _propTypes.default.number,
    /**
   * Function to change the value of [`selected`](#prop-selected).
   */ setSelected: _propTypes.default.func,
    /**
   * Total number of slides in the [`Carousel`](/apiReference/carousel/Carousel).
   */ count: _propTypes.default.number,
    /**
   * Label given to the left arrow for accessbility purposes.
   */ leftArrowLabel: _propTypes.default.string,
    /**
   * Label given to the right arrow for accessbility purposes.
   */ rightArrowLabel: _propTypes.default.string,
    infinite: _propTypes.default.bool
};
CarouselArrows.defaultProps = {
    leftArrowLabel: 'Previous',
    rightArrowLabel: 'Next'
};

//# sourceMappingURL=CarouselArrows.js.map