"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = MagnifyHint;
var _amp = require("next/amp");
var _styles = require("@mui/material/styles");
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _material = require("@mui/material");
var _iconsMaterial = require("@mui/icons-material");
var _clsx = _interopRequireDefault(require("clsx"));
function _defineProperty(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
var PREFIX = 'RSFMagnifyHint';
var classes = {
    root: "".concat(PREFIX, "-root"),
    wrap: "".concat(PREFIX, "-wrap"),
    icon: "".concat(PREFIX, "-icon"),
    text: "".concat(PREFIX, "-text"),
    over: "".concat(PREFIX, "-over"),
    zoomDisabled: "".concat(PREFIX, "-zoomDisabled"),
    expandDisabled: "".concat(PREFIX, "-expandDisabled"),
    zoomTextDesktop: "".concat(PREFIX, "-zoomTextDesktop"),
    expandTextMobile: "".concat(PREFIX, "-expandTextMobile"),
    expandTextDesktop: "".concat(PREFIX, "-expandTextDesktop")
};
var _obj;
var Root = (0, _styles).styled('div')(function() {
    return _obj = {
    }, /**
   * Styles applied to the root element.
   */ _defineProperty(_obj, "&.".concat(classes.root), {
        position: 'absolute',
        bottom: 30,
        display: 'flex',
        flexDirection: 'row',
        justifyContent: 'center',
        width: '100%'
    }), /**
   * Styles applied to the root element when [`over`](#prop-over) is `true`.
   */ _defineProperty(_obj, "&.".concat(classes.over), {
    }), /**
   * Styles applied to the root element when [`zoomDisabled`](#prop-zoomDisabled) is `true`.
   */ _defineProperty(_obj, "&.".concat(classes.zoomDisabled), {
    }), /**
   * Styles applied to the root element when [`expandDisabled`](#prop-expandDisabled) is `true`.
   */ _defineProperty(_obj, "&.".concat(classes.expandDisabled), // hide the whole component when:
    // - both zoom and expand are disabled
    // - expand is disabled and user is mobile
    _defineProperty({
    }, "&.".concat(classes.zoomDisabled), {
        display: 'none',
        '@media (hover: none) and (pointer: coarse)': {
            display: 'none'
        }
    })), _obj;
});
var Wrap = (0, _styles).styled('div')(function() {
    return _defineProperty({
    }, "&.".concat(classes.wrap), {
        borderRadius: 25,
        backgroundColor: 'rgba(0, 0, 0, 0.3)',
        lineHeight: 14,
        padding: '5px 10px',
        display: 'flex',
        flexDirection: 'row',
        alignItems: 'center'
    });
});
var StyledIcon = (0, _styles).styled(_iconsMaterial.AddCircleOutline)(function(param) {
    var theme = param.theme;
    return(/**
   * Styles applied to the magnification icon element.
   */ _defineProperty({
    }, "& .".concat(classes.icon), {
        height: 16,
        width: 16,
        color: theme.palette.grey[300]
    }));
});
var _obj1, _obj2, _obj3;
var StyledTypography = (0, _styles).styled(_material.Typography)(function(param) {
    var theme = param.theme;
    return _obj3 = {
    }, /**
   * Styles applied to the elements containing each of the text captions.
   */ _defineProperty(_obj3, "&.".concat(classes.text), {
        marginLeft: 5,
        color: theme.palette.grey[300],
        position: 'relative',
        top: 1
    }), _defineProperty(_obj3, "&.".concat(classes.zoomTextDesktop), (_obj1 = {
        display: 'block'
    }, // hide zoom text when:
    // - hovering + expand is enabled
    // - zoom is disabled
    // - mobile user
    _defineProperty(_obj1, ".".concat(classes.over, ":not(.").concat(classes.expandDisabled, ") &, .").concat(classes.zoomDisabled, " &"), {
        display: 'none'
    }), _defineProperty(_obj1, '@media (hover: none) and (pointer: coarse)', {
        display: 'none'
    }), _obj1)), /**
   * Styles applied to the element containing the [expandTextMobile](#prop-expandTextMobile) caption.
   */ _defineProperty(_obj3, "&.".concat(classes.expandTextMobile), {
        display: 'none',
        '@media (hover: none) and (pointer: coarse)': {
            display: 'block'
        }
    }), _defineProperty(_obj3, "&.".concat(classes.expandTextDesktop), (_obj2 = {
        display: 'none'
    }, _defineProperty(_obj2, ".".concat(classes.over, ":not(.").concat(classes.expandDisabled, ") &, .").concat(classes.zoomDisabled, " &"), {
        display: 'block'
    }), _defineProperty(_obj2, '@media (hover: none) and (pointer: coarse)', {
        display: 'none'
    }), _obj2)), _obj3;
});
var _obj4;
function MagnifyHint(param) {
    var zoomTextDesktop = param.zoomTextDesktop, expandTextMobile = param.expandTextMobile, expandTextDesktop = param.expandTextDesktop, over = param.over, className = param.className, disableZoom = param.disableZoom, disableExpand = param.disableExpand;
    var isAmp = (0, _amp).useAmp();
    disableZoom = disableZoom || isAmp;
    return(/*#__PURE__*/ _react.default.createElement(Root, {
        className: (0, _clsx).default(className, (_obj4 = {
        }, _defineProperty(_obj4, classes.root, true), _defineProperty(_obj4, classes.over, over), _defineProperty(_obj4, classes.zoomDisabled, disableZoom), _defineProperty(_obj4, classes.expandDisabled, disableExpand), _obj4))
    }, /*#__PURE__*/ _react.default.createElement(Wrap, {
        className: classes.wrap
    }, /*#__PURE__*/ _react.default.createElement(StyledIcon, {
        className: classes.icon,
        alt: "magnify-icon"
    }), /*#__PURE__*/ _react.default.createElement(StyledTypography, {
        variant: "caption",
        className: (0, _clsx).default(classes.text, classes.zoomTextDesktop)
    }, zoomTextDesktop), /*#__PURE__*/ _react.default.createElement(StyledTypography, {
        variant: "caption",
        className: (0, _clsx).default(classes.text, classes.expandTextMobile)
    }, expandTextMobile), /*#__PURE__*/ _react.default.createElement(StyledTypography, {
        variant: "caption",
        className: (0, _clsx).default(classes.text, classes.expandTextDesktop)
    }, expandTextDesktop))));
}
MagnifyHint.propTypes = {
    /**
   * Override or extend the styles applied to the component. See [CSS API](#css) below for more details.
   */ classes: _propTypes.default.object,
    /**
   * CSS class to apply to the root element.
   */ className: _propTypes.default.string,
    /**
   * The text displayed to tell the user to hover to zoom.
   */ zoomTextDesktop: _propTypes.default.string,
    /**
   * The text displayed to tell a mobile user to tap to expand.
   */ expandTextMobile: _propTypes.default.string,
    /**
   * The text displayed to tell a desktop user to click to expand.
   */ expandTextDesktop: _propTypes.default.string,
    /**
   * If `true`, zooming is disabled and the hint for zooming is not shown.
   */ disableZoom: _propTypes.default.bool,
    /**
   * If `true`, expanding is disabled and the hint for expanding is not shown.
   */ disableExpand: _propTypes.default.bool,
    over: _propTypes.default.bool
};
MagnifyHint.defaultProps = {
    zoomTextDesktop: 'Hover to Zoom',
    expandTextMobile: 'Tap to Expand',
    expandTextDesktop: 'Click to Expand'
};

//# sourceMappingURL=MagnifyHint.js.map