"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = useIntersectionObserver;
var _react = require("react");
function _instanceof(left, right) {
    if (right != null && typeof Symbol !== "undefined" && right[Symbol.hasInstance]) {
        return right[Symbol.hasInstance](left);
    } else {
        return left instanceof right;
    }
}
function getElement(ref) {
    if (ref && ref.current) {
        return ref.current;
    }
    return ref;
}
function useIntersectionObserver(getRef, cb, deps, notSupportedCallback) {
    (0, _react).useEffect(function() {
        if (!window.IntersectionObserver) {
            notSupportedCallback && notSupportedCallback(new Error('IntersectionObserver is not available'));
            return;
        }
        var observer = new IntersectionObserver(function(entries) {
            // if intersectionRatio is 0, the element is out of view and we do not need to do anything.
            cb(entries[0].intersectionRatio > 0, function() {
                return observer.disconnect();
            });
        });
        var el = getElement(getRef());
        if (_instanceof(el, Element)) {
            observer.observe(el);
            return function() {
                return observer.disconnect();
            };
        }
    }, deps);
}

//# sourceMappingURL=useIntersectionObserver.js.map