"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = useLazyState;
var _react = require("react");
var _router = require("next/router");
var _get = _interopRequireDefault(require("lodash/get"));
var _merge = _interopRequireDefault(require("../utils/merge"));
var _linkContext = _interopRequireDefault(require("../link/LinkContext"));
var _storeInitialPropsInHistory = _interopRequireDefault(require("../router/storeInitialPropsInHistory"));
function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
}
function _defineProperty(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
function _iterableToArrayLimit(arr, i) {
    var _arr = [];
    var _n = true;
    var _d = false;
    var _e = undefined;
    try {
        for(var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true){
            _arr.push(_s.value);
            if (i && _arr.length === i) break;
        }
    } catch (err) {
        _d = true;
        _e = err;
    } finally{
        try {
            if (!_n && _i["return"] != null) _i["return"]();
        } finally{
            if (_d) throw _e;
        }
    }
    return _arr;
}
function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
}
function _objectSpread(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {
        };
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === "function") {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _defineProperty(target, key, source[key]);
        });
    }
    return target;
}
function _objectWithoutProperties(source, excluded) {
    if (source == null) return {
    };
    var target = _objectWithoutPropertiesLoose(source, excluded);
    var key, i;
    if (Object.getOwnPropertySymbols) {
        var sourceSymbolKeys = Object.getOwnPropertySymbols(source);
        for(i = 0; i < sourceSymbolKeys.length; i++){
            key = sourceSymbolKeys[i];
            if (excluded.indexOf(key) >= 0) continue;
            if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
            target[key] = source[key];
        }
    }
    return target;
}
function _objectWithoutPropertiesLoose(source, excluded) {
    if (source == null) return {
    };
    var target = {
    };
    var sourceKeys = Object.keys(source);
    var key, i;
    for(i = 0; i < sourceKeys.length; i++){
        key = sourceKeys[i];
        if (excluded.indexOf(key) >= 0) continue;
        target[key] = source[key];
    }
    return target;
}
function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
}
(0, _storeInitialPropsInHistory).default();
function useLazyState(lazyProps) {
    var additionalData = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {
    };
    var isInitialMount = (0, _react).useRef(true);
    var Router = (0, _router).useRouter();
    // If linkPageData is null then lodash merge will overwrite everything in additionalData.pageData
    // It will properly merge the values if linkPageData is undefined
    var linkPageData = (0, _get).default((0, _react).useContext(_linkContext.default), 'current') || undefined;
    var lazy = lazyProps.lazy, url = lazyProps.url, props1 = _objectWithoutProperties(lazyProps, [
        "lazy",
        "url"
    ]);
    var createInitialState = function() {
        return (0, _merge).default({
        }, additionalData, {
            pageData: linkPageData
        }, props1, {
            loading: lazyProps.lazy != null,
            pageData: {
            }
        });
    };
    var goingBack = (0, _react).useRef(false);
    var ref = _slicedToArray((0, _react).useState(createInitialState), 2), state1 = ref[0], setState = ref[1];
    var stateRef = (0, _react).useRef(state1);
    var updateState = function(finalState) {
        if (typeof finalState !== 'function') {
            stateRef.current = finalState;
            return setState(finalState);
        }
        return setState(function(state) {
            stateRef.current = finalState(state);
            return stateRef.current;
        });
    };
    (0, _react).useEffect(function() {
        if (stateRef.current.loading && !isInitialMount.current) {
            return;
        }
        if (lazyProps.lazy) {
            updateState(function(state) {
                return _objectSpread({
                }, state, {
                    loading: true
                });
            });
            lazy.then(function(props) {
                return updateState((0, _merge).default({
                }, additionalData, {
                    pageData: linkPageData
                }, props, {
                    loading: false
                }));
            });
        } else if (!isInitialMount.current) {
            // there is no need to do this if we just mounted since createInitialState will return the same thing as the current state
            updateState(createInitialState());
        }
    }, [
        lazyProps
    ]);
    (0, _react).useEffect(function() {
        isInitialMount.current = false;
        if (process.env.NODE_ENV !== 'production') {
            // expose a global function that makes it easy to toggle skeletons during development via chrome develeoper console
            window.rsf_toggleLoading = function() {
                return updateState(function(state) {
                    return _objectSpread({
                    }, state, {
                        loading: !state.loading
                    });
                });
            };
            return function() {
                return delete window.rsf_toggleLoading;
            };
        }
    }, []);
    // save the page state in history.state before navigation
    var onHistoryChange = (0, _react).useCallback(function() {
        if (!goingBack.current && !stateRef.current.loading) {
            // We don't record pageData in history here because the browser has already changed the
            // URL to the previous page.  It's too late.  This means that going forward will always result
            // in a fetch (though usually this will just come from the browser's cache)
            recordState(stateRef.current.pageData);
        }
    }, [
        recordState
    ]);
    (0, _react).useEffect(function() {
        Router.beforePopState(function() {
            goingBack.current = true;
            return true;
        });
        Router.events.on('routeChangeStart', onHistoryChange);
        Router.events.on('routeChangeComplete', resetGoingBack);
        return function() {
            Router.events.off('routeChangeStart', onHistoryChange);
            Router.events.off('routeChangeComplete', resetGoingBack);
        };
    }, []);
    var resetGoingBack = (0, _react).useCallback(function() {
        goingBack.current = false;
    }, []);
    return [
        state1,
        updateState
    ];
}
/**
 * Records the page state in history.state.rsf[uri].  Why is this needed?  Why can we not
 * simply rely on the page data being in the browser's cache via the service worker? It's
 * because we want to restore the state of the page as the user left it, including sorting,
 * paging, and any other changes which might not be reflected in the URL.
 * @param {Object} state The page state
 */ function recordState(state) {
    var as = location.pathname + location.search + location.hash;
    var historyState = _objectSpread({
    }, history.state, {
        as: as,
        rsf: _defineProperty({
        }, as, state)
    });
    history.replaceState(historyState, document.title, as);
}

//# sourceMappingURL=useLazyState.js.map