"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _link = _interopRequireDefault(require("next/link"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _linkContext = _interopRequireDefault(require("./LinkContext"));
require("@mui/material");
var _useIntersectionObserver = _interopRequireDefault(require("../hooks/useIntersectionObserver"));
var _serviceWorker = require("../serviceWorker");
var _withDefaultHandler = _interopRequireDefault(require("../utils/withDefaultHandler"));
var _getAPIURL = _interopRequireDefault(require("../api/getAPIURL"));
function _defineProperty(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _extends() {
    _extends = Object.assign || function(target) {
        for(var i = 1; i < arguments.length; i++){
            var source = arguments[i];
            for(var key in source){
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key];
                }
            }
        }
        return target;
    };
    return _extends.apply(this, arguments);
}
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
        return obj;
    } else {
        var newObj = {
        };
        if (obj != null) {
            for(var key in obj){
                if (Object.prototype.hasOwnProperty.call(obj, key)) {
                    var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {
                    };
                    if (desc.get || desc.set) {
                        Object.defineProperty(newObj, key, desc);
                    } else {
                        newObj[key] = obj[key];
                    }
                }
            }
        }
        newObj.default = obj;
        return newObj;
    }
}
function _objectSpread(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {
        };
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === "function") {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _defineProperty(target, key, source[key]);
        });
    }
    return target;
}
function _objectWithoutProperties(source, excluded) {
    if (source == null) return {
    };
    var target = _objectWithoutPropertiesLoose(source, excluded);
    var key, i;
    if (Object.getOwnPropertySymbols) {
        var sourceSymbolKeys = Object.getOwnPropertySymbols(source);
        for(i = 0; i < sourceSymbolKeys.length; i++){
            key = sourceSymbolKeys[i];
            if (excluded.indexOf(key) >= 0) continue;
            if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
            target[key] = source[key];
        }
    }
    return target;
}
function _objectWithoutPropertiesLoose(source, excluded) {
    if (source == null) return {
    };
    var target = {
    };
    var sourceKeys = Object.keys(source);
    var key, i;
    for(i = 0; i < sourceKeys.length; i++){
        key = sourceKeys[i];
        if (excluded.indexOf(key) >= 0) continue;
        target[key] = source[key];
    }
    return target;
}
/**
 * Use this component for all Links in your React Storefront app.  You can
 * pass props to display on the next page while data is loading from the server
 * using the `pageData` prop. This component accepts all props that would
 * normally be passed to a [Next.js `Link` component](https://nextjs.org/docs/api-reference/next/link).
 * All other props are spread to the underlying HTML anchor element.
 *
 * Example:
 *
 * ```js
 * import Link from 'react-storefront/link/Link'
 *
 * <Link href="/p/[productId]" as={`/p/${product.id}`} pageData={{ product }}>
 *   {product.name}
 * </Link>
 * ```
 */ var Link = function Link(_param) {
    var as = _param.as, href = _param.href, prefetch = _param.prefetch, prefetchURL = _param.prefetchURL, pageData = _param.pageData, onClick = _param.onClick, children = _param.children, other = _objectWithoutProperties(_param, [
        "as",
        "href",
        "prefetch",
        "prefetchURL",
        "pageData",
        "onClick",
        "children"
    ]);
    var ref = (0, _react).useRef(null);
    var linkPageData = (0, _react).useContext(_linkContext.default);
    var handleClick = (0, _withDefaultHandler).default(onClick, function() {
        if (linkPageData) {
            linkPageData.current = pageData;
        }
    });
    prefetchURL = prefetchURL || as && (0, _getAPIURL).default(as);
    (0, _useIntersectionObserver).default(function() {
        return prefetchURL && prefetch === 'visible' ? ref : null;
    }, function(visible, disconnect) {
        if (visible && prefetchURL) {
            disconnect();
            (0, _serviceWorker).prefetch(prefetchURL);
        }
    }, [
        prefetchURL,
        prefetch
    ]);
    (0, _react).useEffect(function() {
        if (prefetch === 'always' && prefetchURL) {
            (0, _serviceWorker).prefetch(prefetchURL);
        }
    }, [
        prefetchURL
    ]);
    if (!children || typeof children === 'string') {
        return(/*#__PURE__*/ _react.default.createElement(_link.default, {
            href: href,
            prefetch: false,
            as: as,
            passHref: true
        }, /*#__PURE__*/ _react.default.createElement("a", _extends({
            ref: ref
        }, other, {
            onClick: handleClick
        }), children)));
    }
    var child = _react.default.Children.only(children);
    var passHref = !child.props.href // we only passHref if the child does not have an href prop already.  This fixes a bug with AMP where NextLink overrides and escapes amp-bind syntax in hrefs.
    ;
    // This way we can get a ref of Material-ui components
    return(/*#__PURE__*/ _react.default.createElement(_link.default, {
        href: href,
        prefetch: false,
        as: as,
        passHref: passHref
    }, /*#__PURE__*/ _react.default.cloneElement(children, _objectSpread({
        onClick: handleClick
    }, other))));
};
Link.propTypes = {
    /**
   * The URL path for the underlying anchor element's `href`.  This is required for dynamic routes.
   */ as: _propTypes.default.string,
    /**
   * The next.js route pattern
   */ href: _propTypes.default.string.isRequired,
    /**
   * Set to `visible` to prefetch the JSON data for the destination page component when the link
   * is scrolled into the viewport.  Set to `always` to prefetch the data immediately. Set to
   * `false` to never prefetch.
   */ prefetch: _propTypes.default.oneOf([
        'always',
        'visible',
        false
    ]),
    /**
   * The URL to prefetch.  If omitted, `/api/{href}` will be prefetched.
   */ prefetchURL: _propTypes.default.string,
    /**
   * Data to be added to the `pageData` key returned by [`/hooks/useLazyState`](/apiReference/hooks/useLazyState)
   * in the destination page component.  Use this to display partial data in the skeleton while the full dataset
   * is fetched from the server.
   */ pageData: _propTypes.default.object,
    /**
   * An optional function to run when the Link is clicked.
   */ onClick: _propTypes.default.func,
    /**
   * Content children of the link element.
   */ children: _propTypes.default.node
};
var _default = Link;
exports.default = _default;

//# sourceMappingURL=Link.js.map