"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = MenuItemContent;
var _react = _interopRequireWildcard(require("react"));
var _styles = require("@mui/material/styles");
var _material = require("@mui/material");
var _clsx = _interopRequireDefault(require("clsx"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _menuContext = _interopRequireDefault(require("./MenuContext"));
var _menuExpanderIcon = _interopRequireDefault(require("./MenuExpanderIcon"));
function _defineProperty(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _extends() {
    _extends = Object.assign || function(target) {
        for(var i = 1; i < arguments.length; i++){
            var source = arguments[i];
            for(var key in source){
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key];
                }
            }
        }
        return target;
    };
    return _extends.apply(this, arguments);
}
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
        return obj;
    } else {
        var newObj = {
        };
        if (obj != null) {
            for(var key in obj){
                if (Object.prototype.hasOwnProperty.call(obj, key)) {
                    var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {
                    };
                    if (desc.get || desc.set) {
                        Object.defineProperty(newObj, key, desc);
                    } else {
                        newObj[key] = obj[key];
                    }
                }
            }
        }
        newObj.default = obj;
        return newObj;
    }
}
function _objectSpread(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {
        };
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === "function") {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _defineProperty(target, key, source[key]);
        });
    }
    return target;
}
var PREFIX = 'RSFMenuItemContent';
var classes = {
    listItem: "".concat(PREFIX, "-listItem"),
    listItemImage: "".concat(PREFIX, "-listItemImage"),
    listItemIcon: "".concat(PREFIX, "-listItemIcon"),
    loadingIcon: "".concat(PREFIX, "-loadingIcon")
};
var _obj;
var StyledListItem = (0, _styles).styled(_material.ListItem)(function(param) {
    var theme = param.theme;
    return _obj = {
    }, _defineProperty(_obj, "& .".concat(classes.listItem), {
        textTransform: 'uppercase',
        lineHeight: '1.5',
        fontSize: theme.typography.body1.fontSize
    }), _defineProperty(_obj, "& .".concat(classes.listItemImage), {
        width: '40px',
        height: '40px',
        marginRight: 0
    }), _defineProperty(_obj, "& .".concat(classes.listItemIcon), {
        marginRight: 0,
        minWidth: 0
    }), _defineProperty(_obj, "& .".concat(classes.loadingIcon), {
        display: 'block'
    }), _obj;
});
var _obj1;
var StyledListItemText = (0, _styles).styled(_material.ListItemText)(function(param) {
    var theme = param.theme;
    return _obj1 = {
    }, _defineProperty(_obj1, "& .".concat(classes.drawer), {
        zIndex: theme.zIndex.modal + 20,
        display: 'flex',
        flexDirection: 'column',
        borderTop: "".concat(theme.headerHeight, "px solid transparent"),
        'body.moov-safari &': {
            // Turning off momentum scrolling on iOS here to fix frozen body issue
            // Source: https://moovweb.atlassian.net/browse/PRPL-342
            '-webkit-overflow-scrolling': 'auto'
        }
    }), _defineProperty(_obj1, "& .".concat(classes.list), {
        flex: 'none',
        overflowY: 'auto',
        overflowX: 'hidden',
        maxHeight: '100%',
        padding: 0
    }), _defineProperty(_obj1, "& .".concat(classes.listPadding), {
        padding: 0
    }), _defineProperty(_obj1, "& .".concat(classes.header), {
        position: 'absolute',
        left: '10px',
        top: '12px'
    }), _defineProperty(_obj1, "& .".concat(classes.icon), {
        marginRight: '0',
        width: 24
    }), _defineProperty(_obj1, "& .".concat(classes.headerText), {
        textAlign: 'center',
        fontWeight: '600',
        textTransform: 'uppercase',
        fontSize: theme.typography.body1.fontSize
    }), _defineProperty(_obj1, "& .".concat(classes.bodyWrap), {
        display: 'flex',
        flex: 1,
        flexDirection: 'row',
        transition: 'all ease-out .2s',
        maxHeight: '100%'
    }), _defineProperty(_obj1, "& .".concat(classes.hidden), {
        display: 'none'
    }), _defineProperty(_obj1, "& .".concat(classes.visible), {
        display: 'block'
    }), _defineProperty(_obj1, "& .".concat(classes.link), {
        display: 'block',
        textDecoration: 'none',
        color: 'inherit'
    }), _defineProperty(_obj1, "& .".concat(classes.leaf), _objectSpread({
        textTransform: 'none'
    }, theme.typography.body1)), _defineProperty(_obj1, "& .".concat(classes.drawerFixed), {
        top: 0,
        height: '100vh',
        borderTop: 'none'
    }), _obj1;
});
function MenuItemContent(props) {
    var ref = (0, _react).useContext(_menuContext.default), renderItemContent = ref.renderItemContent, onItemClick = ref.onItemClick;
    var item = props.item, depth = props.depth, leaf = props.leaf, listItemProps = props.listItemProps;
    var contents;
    if (renderItemContent) {
        contents = renderItemContent(item, leaf);
    }
    if (!contents) {
        if (leaf) {
            contents = /*#__PURE__*/ _react.default.createElement(_react.default.Fragment, null, item.image && /*#__PURE__*/ _react.default.createElement(_material.ListItemIcon, null, /*#__PURE__*/ _react.default.createElement("img", {
                className: classes.listItemImage,
                alt: item.text,
                src: item.image
            })), /*#__PURE__*/ _react.default.createElement(_material.ListItemText, {
                primary: item.text,
                disableTypography: true
            }));
        } else {
            contents = /*#__PURE__*/ _react.default.createElement(_react.default.Fragment, null, item.image && /*#__PURE__*/ _react.default.createElement(_material.ListItemIcon, null, /*#__PURE__*/ _react.default.createElement("img", {
                className: classes.listItemImage,
                alt: item.text,
                src: item.image
            })), /*#__PURE__*/ _react.default.createElement(StyledListItemText, {
                className: classes.listItem,
                primary: item.text,
                disableTypography: true
            }), /*#__PURE__*/ _react.default.createElement(_material.ListItemIcon, {
                className: classes.listItemIcon
            }, item.loading ? /*#__PURE__*/ _react.default.createElement(_material.CircularProgress, {
                style: {
                    height: 24,
                    width: 24,
                    padding: 4
                },
                color: "secondary",
                className: classes.loadingIcon
            }) : /*#__PURE__*/ _react.default.createElement(_menuExpanderIcon.default, _extends({
            }, props))));
        }
    }
    return(/*#__PURE__*/ _react.default.createElement(StyledListItem, _extends({
        onClick: leaf ? null : onItemClick.bind(null, item, depth),
        button: true,
        divider: true,
        classes: {
            root: (0, _clsx).default(classes.listItem, item.className)
        }
    }, listItemProps), contents));
}
MenuItemContent.propTypes = {
    /**
   * Additional props for the underlying ListItem
   */ listItemProps: _propTypes.default.object,
    item: _propTypes.default.object,
    depth: _propTypes.default.number,
    leaf: _propTypes.default.bool
};

//# sourceMappingURL=MenuItemContent.js.map