"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = ProductOption;
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _get = _interopRequireDefault(require("lodash/get"));
var _textProductOption = _interopRequireDefault(require("./TextProductOption"));
var _swatchProductOption = _interopRequireDefault(require("./SwatchProductOption"));
var _withDefaultHandler = _interopRequireDefault(require("../utils/withDefaultHandler"));
function _defineProperty(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _extends() {
    _extends = Object.assign || function(target) {
        for(var i = 1; i < arguments.length; i++){
            var source = arguments[i];
            for(var key in source){
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key];
                }
            }
        }
        return target;
    };
    return _extends.apply(this, arguments);
}
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
function _objectSpread(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {
        };
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === "function") {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _defineProperty(target, key, source[key]);
        });
    }
    return target;
}
function _objectWithoutProperties(source, excluded) {
    if (source == null) return {
    };
    var target = _objectWithoutPropertiesLoose(source, excluded);
    var key, i;
    if (Object.getOwnPropertySymbols) {
        var sourceSymbolKeys = Object.getOwnPropertySymbols(source);
        for(i = 0; i < sourceSymbolKeys.length; i++){
            key = sourceSymbolKeys[i];
            if (excluded.indexOf(key) >= 0) continue;
            if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
            target[key] = source[key];
        }
    }
    return target;
}
function _objectWithoutPropertiesLoose(source, excluded) {
    if (source == null) return {
    };
    var target = {
    };
    var sourceKeys = Object.keys(source);
    var key, i;
    for(i = 0; i < sourceKeys.length; i++){
        key = sourceKeys[i];
        if (excluded.indexOf(key) >= 0) continue;
        target[key] = source[key];
    }
    return target;
}
function ProductOption(props) {
    var value = props.value, selected = props.selected, selectedOption = props.selectedOption, onSelectedOptionChange = props.onSelectedOptionChange, onClick = props.onClick, variant = props.variant, showLabel = props.showLabel, wrapperProps = props.wrapperProps, optionProps = props.optionProps, selectedClassName = props.selectedClassName, others = _objectWithoutProperties(props, [
        "value",
        "selected",
        "selectedOption",
        "onSelectedOptionChange",
        "onClick",
        "variant",
        "showLabel",
        "wrapperProps",
        "optionProps",
        "selectedClassName"
    ]);
    if (selectedOption) {
        selected = (0, _get).default(value, 'id') == (0, _get).default(selectedOption, 'id');
    }
    var handleClick = (0, _withDefaultHandler).default(onClick, function() {
        if (onSelectedOptionChange) {
            onSelectedOptionChange(selected ? null : value);
        }
    });
    var Variant = variant === 'text' ? _textProductOption.default : _swatchProductOption.default;
    var propArgs = _objectSpread({
        selected: selected
    }, props);
    return(/*#__PURE__*/ _react.default.createElement("div", _extends({
        className: selected ? selectedClassName : ''
    }, wrapperProps(propArgs)), /*#__PURE__*/ _react.default.createElement(Variant, _extends({
    }, others, optionProps(propArgs), {
        label: showLabel ? value && value.text : undefined,
        selected: selected,
        onClick: handleClick,
        disabled: (0, _get).default(value, 'disabled')
    }))));
}
ProductOption.propTypes = {
    /**
   * The UI variant that controls how the option is displayed.
   */ variant: _propTypes.default.oneOf([
        'text',
        'swatch'
    ]).isRequired,
    /**
   * Set to `false` to hide the label text.
   */ showLabel: _propTypes.default.bool,
    /**
   * The CSS class name applied to a selected option.
   */ selectedClassName: _propTypes.default.string,
    /**
   * The value for the product option.
   */ value: _propTypes.default.object,
    /**
   * If `true`, this option is the selected option.
   */ selected: _propTypes.default.bool,
    /**
   * An alternative to using [`selected`](#prop-selected), this is a value that will be tested against
   * the [`value`](#prop-value) prop to determine if this option is selected.
   */ selectedOption: _propTypes.default.object,
    /**
   * Called when the selected option is changed.
   */ onSelectedOptionChange: _propTypes.default.func,
    /**
   * Called with this option is clicked.
   */ onClick: _propTypes.default.func,
    /**
   * A function that returns props to pass to the wrapper element.
   */ wrapperProps: _propTypes.default.func,
    /**
   * A function that returns props to pass to the option element.
   */ optionProps: _propTypes.default.func
};
ProductOption.defaultProps = {
    showLabel: true,
    wrapperProps: Function.prototype,
    optionProps: Function.prototype,
    selectedClassName: 'rsf-po-selected'
};

//# sourceMappingURL=ProductOption.js.map