"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = TextProductOption;
var _react = _interopRequireDefault(require("react"));
var _styles = require("@mui/material/styles");
var _propTypes = _interopRequireDefault(require("prop-types"));
var _clsx = _interopRequireDefault(require("clsx"));
var _material = require("@mui/material");
function _defineProperty(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _extends() {
    _extends = Object.assign || function(target) {
        for(var i = 1; i < arguments.length; i++){
            var source = arguments[i];
            for(var key in source){
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key];
                }
            }
        }
        return target;
    };
    return _extends.apply(this, arguments);
}
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
function _objectSpread(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {
        };
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === "function") {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _defineProperty(target, key, source[key]);
        });
    }
    return target;
}
var PREFIX = 'RSFTextProductOption';
var defaultClasses = {
    root: "".concat(PREFIX, "-root"),
    strikeThrough: "".concat(PREFIX, "-strikeThrough")
};
var _obj;
// TODO jss-to-styled codemod: The Fragment root was replaced by div. Change the tag if needed.
var Root = (0, _styles).styled('div')(function(param) {
    var theme = param.theme;
    return _obj = {
    }, /**
   * Styles applied to the root element.
   */ _defineProperty(_obj, "&.".concat(defaultClasses.root), {
        '.rsf-po-selected &': {
            borderColor: theme.palette.primary.main,
            backgroundColor: theme.palette.primary.main,
            color: theme.palette.primary.contrastText,
            '&:hover': {
                borderColor: theme.palette.primary.main,
                backgroundColor: theme.palette.primary.main,
                color: theme.palette.primary.contrastText
            }
        }
    }), /**
   * Styles applied to the element used as a strikethrough when [`disabled`](#prop-disabled) and
   * [`strikeThroughDisabled`](#prop-disabled) are both `true`.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.strikeThrough), {
        height: '7px',
        borderWidth: '2px 0',
        borderStyle: 'solid',
        borderColor: '#f2f2f2',
        backgroundColor: '#666',
        position: 'relative',
        width: '100%',
        top: 'calc(-(-50% - 2px))',
        left: -2,
        borderRadius: 10
    }), _obj;
});
function TextProductOption(param) {
    var tmp = param.classes, c = tmp === void 0 ? {
    } : tmp, className = param.className, selected = param.selected, label = param.label, skeleton = param.skeleton, buttonProps = param.buttonProps, onClick = param.onClick, disabled = param.disabled, strikeThroughDisabled = param.strikeThroughDisabled, strikeThroughAngle = param.strikeThroughAngle;
    var classes = _objectSpread({
    }, defaultClasses, c);
    if (skeleton) {
        return(/*#__PURE__*/ _react.default.createElement(_material.Skeleton, {
            className: className,
            width: 64,
            height: 36
        }));
    }
    return(/*#__PURE__*/ _react.default.createElement(Root, {
        className: classes.root
    }, /*#__PURE__*/ _react.default.createElement(_material.Button, _extends({
    }, buttonProps, {
        disabled: disabled,
        className: (0, _clsx).default(className, classes.root),
        variant: selected ? 'contained' : 'outlined',
        color: selected ? 'primary' : 'secondary',
        onClick: onClick
    }), label), disabled && strikeThroughDisabled && /*#__PURE__*/ _react.default.createElement("div", {
        className: classes.strikeThrough,
        style: {
            transform: "rotate(".concat(strikeThroughAngle, "deg)")
        }
    })));
}
TextProductOption.propTypes = {
    /**
   * Override or extend the styles applied to the component. See [CSS API](#css) below for more details.
   */ classes: _propTypes.default.object,
    /**
   * A CSS class to apply to the option.
   */ className: _propTypes.default.string,
    /**
   * Set to `true` to display a skeleton instead of the actual button.
   */ skeleton: _propTypes.default.bool,
    /**
   * The text for the button.
   */ label: _propTypes.default.oneOfType([
        _propTypes.default.string,
        _propTypes.default.element
    ]).isRequired,
    /**
   * Set to `true` to mark the option as selected.
   */ selected: _propTypes.default.bool,
    /**
   * Set to `true` to make the option disabled.
   */ disabled: _propTypes.default.bool,
    /**
   * Set to `true` to show a slash through the item when disabled.
   */ strikeThroughDisabled: _propTypes.default.bool,
    /**
   * The angle in degrees for the disabled indicator.
   */ strikeThroughAngle: _propTypes.default.number,
    /**
   * This prop is intentionally ignored so that `TextProductOption` can be used interchangeably with
   * `SwatchProductOption without` displaying a warning.
   */ imageProps: _propTypes.default.object,
    /**
   * Props to pass to the button element.
   */ buttonProps: _propTypes.default.object,
    /**
   * A function to call when this option is clicked.
   */ onClick: _propTypes.default.func
};
TextProductOption.defaultProps = {
    selected: false,
    strikeThroughDisabled: false,
    strikeThroughAngle: 27
};

//# sourceMappingURL=TextProductOption.js.map