"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = ButtonFilterGroup;
var _propTypes = _interopRequireDefault(require("prop-types"));
var _styles = require("@mui/material/styles");
var _react = _interopRequireWildcard(require("react"));
var _searchResultsContext = _interopRequireDefault(require("./SearchResultsContext"));
var _swatchProductOption = _interopRequireDefault(require("../option/SwatchProductOption"));
var _textProductOption = _interopRequireDefault(require("../option/TextProductOption"));
var _box = require("../Box");
function _arrayWithoutHoles(arr) {
    if (Array.isArray(arr)) {
        for(var i = 0, arr2 = new Array(arr.length); i < arr.length; i++){
            arr2[i] = arr[i];
        }
        return arr2;
    }
}
function _defineProperty(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _extends() {
    _extends = Object.assign || function(target) {
        for(var i = 1; i < arguments.length; i++){
            var source = arguments[i];
            for(var key in source){
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key];
                }
            }
        }
        return target;
    };
    return _extends.apply(this, arguments);
}
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
        return obj;
    } else {
        var newObj = {
        };
        if (obj != null) {
            for(var key in obj){
                if (Object.prototype.hasOwnProperty.call(obj, key)) {
                    var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {
                    };
                    if (desc.get || desc.set) {
                        Object.defineProperty(newObj, key, desc);
                    } else {
                        newObj[key] = obj[key];
                    }
                }
            }
        }
        newObj.default = obj;
        return newObj;
    }
}
function _iterableToArray(iter) {
    if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter);
}
function _nonIterableSpread() {
    throw new TypeError("Invalid attempt to spread non-iterable instance");
}
function _objectSpread(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {
        };
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === "function") {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _defineProperty(target, key, source[key]);
        });
    }
    return target;
}
function _toConsumableArray(arr) {
    return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread();
}
var PREFIX = 'RSFButtonFilterGroup';
var defaultClasses = {
    root: "".concat(PREFIX, "-root"),
    matches: "".concat(PREFIX, "-matches"),
    button: "".concat(PREFIX, "-button")
};
var _obj;
var Root = (0, _styles).styled('div')(function(param) {
    var theme = param.theme;
    return _obj = {
    }, /**
   * Styles applied to the root element.
   */ _defineProperty(_obj, "&.".concat(defaultClasses.root), {
        display: 'flex',
        flexWrap: 'wrap'
    }), /**
   * Styles applied to the matching text.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.matches), _objectSpread({
        display: 'inline'
    }, theme.typography.caption, {
        marginLeft: 2,
        color: theme.palette.grey[700]
    })), /**
   * Styles applied to each button element.
   */ _defineProperty(_obj, "& .".concat(defaultClasses.button), {
        fontWeight: 'normal',
        margin: theme.spacing(0, 0.5, 0.5, 0)
    }), _obj;
});
function ButtonFilterGroup(props) {
    var group = props.group, submitOnChange = props.submitOnChange, tmp = props.classes, c = tmp === void 0 ? {
    } : tmp;
    var ref = (0, _react).useContext(_searchResultsContext.default), filters = ref.pageData.filters, toggleFilter = ref.actions.toggleFilter;
    var classes = _objectSpread({
    }, defaultClasses, c);
    return (0, _react).useMemo(function() {
        /*#__PURE__*/ return _react.default.createElement(Root, {
            className: classes.root
        }, group.options.map(function(facet, i) {
            var selected = filters.indexOf(facet.code) !== -1;
            var image = facet.image, matches = facet.matches, name = facet.name;
            var handleClick = function() {
                return toggleFilter(facet, submitOnChange);
            };
            var Variant = image ? _swatchProductOption.default : _textProductOption.default;
            return(/*#__PURE__*/ _react.default.createElement(Variant, _extends({
                key: i,
                classes: {
                    root: classes.button
                },
                selected: selected,
                onClick: handleClick,
                label: /*#__PURE__*/ _react.default.createElement(_box.Hbox, null, /*#__PURE__*/ _react.default.createElement("span", null, name), matches ? /*#__PURE__*/ _react.default.createElement("span", {
                    className: classes.matches
                }, "(", matches, ")") : null)
            }, image ? {
                imageProps: facet.image
            } : undefined)));
        }));
    }, [
        filters
    ].concat(_toConsumableArray(Object.values(props))));
}
ButtonFilterGroup.propTypes = {
    /**
   * Override or extend the styles applied to the component. See [CSS API](#css) below for more details.
   */ classes: _propTypes.default.object,
    /**
   * Contains data for the group to be rendered.
   */ group: _propTypes.default.shape({
        options: _propTypes.default.arrayOf(_propTypes.default.shape({
            code: _propTypes.default.string,
            name: _propTypes.default.string,
            matches: _propTypes.default.oneOfType([
                _propTypes.default.string,
                _propTypes.default.number
            ]),
            image: _propTypes.default.object
        }))
    }),
    /**
   * Set to `true` if the filters will be submitted when changed. In this case, the footer will not be shown.
   */ submitOnChange: _propTypes.default.bool
};

//# sourceMappingURL=ButtonFilterGroup.js.map