"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = FacetGroup;
var _propTypes = _interopRequireDefault(require("prop-types"));
var _styles = require("@mui/material/styles");
var _react = _interopRequireWildcard(require("react"));
var _listItem = _interopRequireDefault(require("@mui/material/ListItem"));
var _searchResultsContext = _interopRequireDefault(require("./SearchResultsContext"));
var _expandableSection = _interopRequireDefault(require("../ExpandableSection"));
var _checkboxFilterGroup = _interopRequireDefault(require("./CheckboxFilterGroup"));
var _buttonFilterGroup = _interopRequireDefault(require("./ButtonFilterGroup"));
function _arrayWithoutHoles(arr) {
    if (Array.isArray(arr)) {
        for(var i = 0, arr2 = new Array(arr.length); i < arr.length; i++){
            arr2[i] = arr[i];
        }
        return arr2;
    }
}
function _defineProperty(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _extends() {
    _extends = Object.assign || function(target) {
        for(var i = 1; i < arguments.length; i++){
            var source = arguments[i];
            for(var key in source){
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key];
                }
            }
        }
        return target;
    };
    return _extends.apply(this, arguments);
}
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
        return obj;
    } else {
        var newObj = {
        };
        if (obj != null) {
            for(var key in obj){
                if (Object.prototype.hasOwnProperty.call(obj, key)) {
                    var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {
                    };
                    if (desc.get || desc.set) {
                        Object.defineProperty(newObj, key, desc);
                    } else {
                        newObj[key] = obj[key];
                    }
                }
            }
        }
        newObj.default = obj;
        return newObj;
    }
}
function _iterableToArray(iter) {
    if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter);
}
function _nonIterableSpread() {
    throw new TypeError("Invalid attempt to spread non-iterable instance");
}
function _objectSpread(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {
        };
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === "function") {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _defineProperty(target, key, source[key]);
        });
    }
    return target;
}
function _toConsumableArray(arr) {
    return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread();
}
var PREFIX = 'RSFFacetGroup';
var defaultClasses = {
    groupTitle: "".concat(PREFIX, "-groupTitle")
};
var StyledExpandableSection = (0, _styles).styled(_expandableSection.default)(function(param) {
    var theme = param.theme;
    return(/**
   * Styles applied to the group's title element.
   */ _defineProperty({
    }, "& .".concat(defaultClasses.groupTitle), _defineProperty({
    }, theme.breakpoints.up('sm'), {
        fontWeight: 'bold'
    })));
});
function FacetGroup(props) {
    var group = props.group, submitOnChange = props.submitOnChange, defaultExpanded = props.defaultExpanded, ControlsComponent = props.ControlsComponent, controlsProps = props.controlsProps, listItemProps = props.listItemProps, onClose = props.onClose, isSimpleList = props.isSimpleList, tmp = props.classes, c = tmp === void 0 ? {
    } : tmp;
    var classes = _objectSpread({
    }, defaultClasses, c);
    var ref = (0, _react).useContext(_searchResultsContext.default), filters = ref.pageData.filters;
    return (0, _react).useMemo(function() {
        if (!filters) return null;
        var selection = [];
        var _iteratorNormalCompletion = true, _didIteratorError = false, _iteratorError = undefined;
        try {
            for(var _iterator = group.options[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true){
                var option = _step.value;
                if (filters.indexOf(option.code) !== -1) {
                    selection.push(option);
                }
            }
        } catch (err) {
            _didIteratorError = true;
            _iteratorError = err;
        } finally{
            try {
                if (!_iteratorNormalCompletion && _iterator.return != null) {
                    _iterator.return();
                }
            } finally{
                if (_didIteratorError) {
                    throw _iteratorError;
                }
            }
        }
        var Controls = ControlsComponent;
        if (!Controls && group.ui === 'buttons') {
            Controls = _buttonFilterGroup.default;
        } else if (!Controls) {
            Controls = _checkboxFilterGroup.default;
        }
        var caption = null;
        if (selection.length === 1) {
            caption = selection[0].name;
        } else if (selection.length > 0) {
            caption = "".concat(selection.length, " selected");
        }
        if (isSimpleList) {
            return(/*#__PURE__*/ _react.default.createElement(_listItem.default, _extends({
            }, listItemProps), /*#__PURE__*/ _react.default.createElement("span", {
                className: classes.groupTitle
            }, group.name), /*#__PURE__*/ _react.default.createElement(Controls, _extends({
                onClose: onClose,
                group: group,
                submitOnChange: submitOnChange
            }, controlsProps))));
        }
        return(/*#__PURE__*/ _react.default.createElement(StyledExpandableSection, {
            title: group.name,
            caption: caption,
            defaultExpanded: defaultExpanded,
            classes: {
                title: classes.groupTitle
            }
        }, /*#__PURE__*/ _react.default.createElement(Controls, _extends({
            group: group,
            submitOnChange: submitOnChange
        }, controlsProps))));
    }, _toConsumableArray(Object.values(props)).concat([
        filters
    ]));
}
FacetGroup.propTypes = {
    /**
   * Override or extend the styles applied to the component. See [CSS API](#css) below for more details.
   */ classes: _propTypes.default.object,
    // TODO - make this a shape
    /**
   * Contains data for the facet group to be rendered.
   */ group: _propTypes.default.object,
    /**
   * Set to `true` to refresh the results when the user toggles a filter.
   */ submitOnChange: _propTypes.default.bool,
    /**
   * If `true`, the group is expanded by default.
   */ defaultExpanded: _propTypes.default.bool,
    /**
   * Custom component to use own component.
   */ ControlsComponent: _propTypes.default.func,
    controlsProps: _propTypes.default.object,
    onClose: _propTypes.default.func,
    listItemProps: _propTypes.default.object,
    /**
   * If `true` list will be displayed instead of expandable items.
   */ isSimpleList: _propTypes.default.bool
};

//# sourceMappingURL=FacetGroup.js.map