"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = SearchResultsProvider;
var _regeneratorRuntime = _interopRequireDefault(require("regenerator-runtime"));
var _react = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _qs = _interopRequireDefault(require("qs"));
var _searchResultsContext = _interopRequireDefault(require("./SearchResultsContext"));
var _replaceState = _interopRequireDefault(require("../router/replaceState"));
var _getAPIURL = _interopRequireDefault(require("../api/getAPIURL"));
function _arrayWithoutHoles(arr) {
    if (Array.isArray(arr)) {
        for(var i = 0, arr2 = new Array(arr.length); i < arr.length; i++){
            arr2[i] = arr[i];
        }
        return arr2;
    }
}
function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
    try {
        var info = gen[key](arg);
        var value = info.value;
    } catch (error) {
        reject(error);
        return;
    }
    if (info.done) {
        resolve(value);
    } else {
        Promise.resolve(value).then(_next, _throw);
    }
}
function _asyncToGenerator(fn) {
    return function() {
        var self = this, args = arguments;
        return new Promise(function(resolve, reject) {
            var gen = fn.apply(self, args);
            function _next(value) {
                asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
            }
            function _throw(err) {
                asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
            }
            _next(undefined);
        });
    };
}
function _defineProperty(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
        return obj;
    } else {
        var newObj = {
        };
        if (obj != null) {
            for(var key in obj){
                if (Object.prototype.hasOwnProperty.call(obj, key)) {
                    var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {
                    };
                    if (desc.get || desc.set) {
                        Object.defineProperty(newObj, key, desc);
                    } else {
                        newObj[key] = obj[key];
                    }
                }
            }
        }
        newObj.default = obj;
        return newObj;
    }
}
function _iterableToArray(iter) {
    if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter);
}
function _nonIterableSpread() {
    throw new TypeError("Invalid attempt to spread non-iterable instance");
}
function _objectSpread(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {
        };
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === "function") {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _defineProperty(target, key, source[key]);
        });
    }
    return target;
}
function _toConsumableArray(arr) {
    return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread();
}
function SearchResultsProvider(param) {
    var store1 = param.store, updateStore = param.updateStore, queryForState = param.queryForState, children = param.children;
    (0, _react).useEffect(function() {
        if (store1.reloading) {
            var refresh1 = function() {
                var _refresh = _asyncToGenerator(_regeneratorRuntime.default.mark(function _callee() {
                    var query, url, ref, _pageData, products, total;
                    return _regeneratorRuntime.default.wrap(function _callee$(_ctx) {
                        while(1)switch(_ctx.prev = _ctx.next){
                            case 0:
                                query = getQueryForState();
                                url = getURLForState(query);
                                // Don't show page for user
                                delete query.page;
                                (0, _replaceState).default(null, null, getURLForState(query));
                                _ctx.next = 6;
                                return fetch((0, _getAPIURL).default(url)).then(function(res) {
                                    return res.json();
                                });
                            case 6:
                                ref = _ctx.sent;
                                _pageData = ref.pageData;
                                products = _pageData.products;
                                total = _pageData.total;
                                updateStore(function(store) {
                                    return {
                                        reloading: false,
                                        pageData: _objectSpread({
                                        }, store.pageData, {
                                            total: total,
                                            products: store.pageData.page === 0 ? products : store.pageData.products.concat(products)
                                        })
                                    };
                                });
                            case 11:
                            case "end":
                                return _ctx.stop();
                        }
                    }, _callee);
                }));
                function refresh() {
                    return _refresh.apply(this, arguments);
                }
                return refresh;
            }();
            refresh1();
        }
    }, [
        store1
    ]);
    /**
   * Fetches the next page of results
   */ var fetchMore = function() {
        updateStore(function(store) {
            return {
                reloading: true,
                pageData: _objectSpread({
                }, store.pageData, {
                    page: store.pageData.page + 1
                })
            };
        });
    };
    /**
   * Removes all filters
   * @param {Boolean} submit If true, fetches new results from the server
   */ var clearFilters = function(submit) {
        setFilters([], submit);
    };
    /**
   * Switches the state of a filter
   * @param {Object} facet
   * @param {Boolean} submit If true, fetches new results from the server
   */ var toggleFilter = function(facet, submit) {
        var code = facet.code;
        var filters = store1.pageData.filters;
        var nextFilters = _toConsumableArray(filters);
        var index = nextFilters.indexOf(code);
        if (index === -1) {
            nextFilters.push(code);
        } else {
            nextFilters.splice(index, 1);
        }
        setFilters(nextFilters, submit);
    };
    /**
   * Updates the set of selected filters
   * @param {Object[]} filters
   * @param {Boolean} submit If true, fetches new results from the server
   */ var setFilters = function(filters, submit) {
        var filtersChanged = JSON.stringify(filters.map(function(v) {
            return v.toLowerCase();
        }).sort()) !== JSON.stringify(store1.pageData.filters.map(function(v) {
            return v.toLowerCase();
        }).sort());
        updateStore(function(store) {
            return {
                reloading: Boolean(submit),
                pageData: _objectSpread({
                }, store.pageData, {
                    filters: filters,
                    filtersChanged: submit ? false : filtersChanged,
                    page: submit ? 0 : store.pageData.page
                })
            };
        });
    };
    /**
   * Applies the selected filters, resets the page to 0 and fetches new results from the server.
   */ var applyFilters = function() {
        updateStore(function(store) {
            return {
                reloading: true,
                pageData: _objectSpread({
                }, store.pageData, {
                    filtersChanged: false,
                    page: 0
                })
            };
        });
    };
    /**
   * Computes the query for the current state of the search controls
   */ var getQueryForState = function() {
        if (queryForState) return queryForState(store1.pageData);
        var _pageData = store1.pageData, filters = _pageData.filters, page = _pageData.page, sort = _pageData.sort;
        var search = window.location.search;
        var query = _qs.default.parse(search, {
            ignoreQueryPrefix: true
        });
        if (filters.length) {
            query.filters = JSON.stringify(filters);
        } else {
            delete query.filters;
        }
        if (query.more) {
            delete query.more;
        }
        if (page > 0) {
            query.page = page;
        } else {
            delete query.page;
        }
        if (sort) {
            query.sort = sort;
        } else {
            delete query.sort;
        }
        return query;
    };
    /**
   * Computes the URL for the current query of the search controls
   */ var getURLForState = function(query) {
        var _location = window.location, pathname = _location.pathname, hash = _location.hash;
        return pathname + _qs.default.stringify(query, {
            addQueryPrefix: true
        }) + hash;
    };
    var setSort = function(option) {
        updateStore(function(store) {
            return {
                reloading: true,
                pageData: _objectSpread({
                }, store.pageData, {
                    sort: option.code,
                    page: 0
                })
            };
        });
    };
    return(/*#__PURE__*/ _react.default.createElement(_searchResultsContext.default.Provider, {
        value: _objectSpread({
        }, store1, {
            actions: {
                fetchMore: fetchMore,
                toggleFilter: toggleFilter,
                clearFilters: clearFilters,
                applyFilters: applyFilters,
                setSort: setSort,
                setFilters: setFilters
            }
        })
    }, children));
}
SearchResultsProvider.propTypes = {
    /**
   * A store returned from [`useSearchResultsStore`](/apiReference/plp/useSearchResultsStore).
   */ store: _propTypes.default.object.isRequired,
    /**
   * The update function returned from [`useSearchResultsStore`](/apiReference/plp/useSearchResultsStore).
   */ updateStore: _propTypes.default.func.isRequired,
    /**
   * An optional function to customize the URL format for search pages when the user
   * changes filters and sort.
   */ queryForState: _propTypes.default.func
};

//# sourceMappingURL=SearchResultsProvider.js.map