"use strict";
function _defineProperty(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _objectSpread(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {
        };
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === "function") {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _defineProperty(target, key, source[key]);
        });
    }
    return target;
}
var withOffline = require('next-offline');
var join = require('path').join;
module.exports = function withServiceWorker(config) {
    var generateInDevMode = process.env.SERVICE_WORKER === 'true';
    if (generateInDevMode) {
        console.log('> Using service worker in development mode');
    }
    return withOffline(_objectSpread({
    }, config, {
        generateInDevMode: generateInDevMode,
        generateSw: false,
        workboxOpts: {
            swDest: 'static/service-worker.js',
            swSrc: join(process.cwd(), 'sw', 'service-worker.js'),
            // The asset names for page chunks contain square brackets, eg [productId].js
            // Next internally injects these chunks encoded, eg %5BproductId%5D.js
            // For precaching to work the cache keys need to match the name of the assets
            // requested, therefore we need to transform the manifest entries with encoding.
            manifestTransforms: [
                function(manifestEntries) {
                    console.log('> Creating service worker...');
                    var manifest = manifestEntries.filter(function(entry) {
                        return !entry.url.includes('next/dist');
                    }) // these paths fail in development resulting in the service worker not being installed
                    .map(function(entry) {
                        entry.url = encodeURI(entry.url);
                        return entry;
                    });
                    return {
                        manifest: manifest,
                        warnings: []
                    };
                }, 
            ]
        }
    }));
};

//# sourceMappingURL=withServiceWorker.js.map