"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = createLazyProps;
function createLazyProps(fetchCallback) {
    var ref = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {
    }, _timeout = ref.timeout, timeout = _timeout === void 0 ? 100 : _timeout;
    return function(options /* from getInitialProps */ ) {
        if (typeof window === 'undefined') {
            // server
            return fetchCallback(options);
        }
        // client
        var rsf = window.history.state.rsf;
        if (rsf && rsf[options.asPath]) {
            // going back or forward
            /* this is written useLazyState's recordState function when the user navigates (not back) */ return {
                pageData: rsf[options.asPath]
            };
        }
        return new Promise(function(resolve, reject) {
            var fetchPromise = fetchCallback(options);
            setTimeout(function() {
                resolve({
                    lazy: fetchPromise
                });
            }, timeout);
            fetchPromise.then(function(result) {
                resolve(result);
            }).catch(function(e) {
                reject(e);
            });
        });
    };
}

//# sourceMappingURL=createLazyProps.js.map