"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = SearchProvider;
var _regeneratorRuntime = _interopRequireDefault(require("regenerator-runtime"));
var _react = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _searchContext = _interopRequireDefault(require("./SearchContext"));
var _fetch = _interopRequireDefault(require("../fetch"));
var _useDebounce = _interopRequireDefault(require("../utils/useDebounce"));
var _fetchLatest = require("../utils/fetchLatest");
var _getAPIURL = _interopRequireDefault(require("../api/getAPIURL"));
function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
}
function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
    try {
        var info = gen[key](arg);
        var value = info.value;
    } catch (error) {
        reject(error);
        return;
    }
    if (info.done) {
        resolve(value);
    } else {
        Promise.resolve(value).then(_next, _throw);
    }
}
function _asyncToGenerator(fn) {
    return function() {
        var self = this, args = arguments;
        return new Promise(function(resolve, reject) {
            var gen = fn.apply(self, args);
            function _next(value) {
                asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
            }
            function _throw(err) {
                asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
            }
            _next(undefined);
        });
    };
}
function _defineProperty(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
        return obj;
    } else {
        var newObj = {
        };
        if (obj != null) {
            for(var key in obj){
                if (Object.prototype.hasOwnProperty.call(obj, key)) {
                    var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {
                    };
                    if (desc.get || desc.set) {
                        Object.defineProperty(newObj, key, desc);
                    } else {
                        newObj[key] = obj[key];
                    }
                }
            }
        }
        newObj.default = obj;
        return newObj;
    }
}
function _iterableToArrayLimit(arr, i) {
    var _arr = [];
    var _n = true;
    var _d = false;
    var _e = undefined;
    try {
        for(var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true){
            _arr.push(_s.value);
            if (i && _arr.length === i) break;
        }
    } catch (err) {
        _d = true;
        _e = err;
    } finally{
        try {
            if (!_n && _i["return"] != null) _i["return"]();
        } finally{
            if (_d) throw _e;
        }
    }
    return _arr;
}
function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
}
function _objectSpread(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {
        };
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === "function") {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _defineProperty(target, key, source[key]);
        });
    }
    return target;
}
function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
}
var fetch = (0, _fetchLatest).fetchLatest(_fetch.default);
function SearchProvider(param) {
    var children = param.children, query = param.query, initialGroups = param.initialGroups, active = param.active, minQueryLength = param.minQueryLength, debounceTime = param.debounceTime;
    var ref = _slicedToArray((0, _react).useState({
        groups: initialGroups,
        loading: true
    }), 2), state1 = ref[0], setState = ref[1];
    var debouncedQuery = (0, _useDebounce).default(query, debounceTime);
    var fetchSuggestions = _asyncToGenerator(_regeneratorRuntime.default.mark(function _callee(text) {
        var url, groups;
        return _regeneratorRuntime.default.wrap(function _callee$(_ctx) {
            while(1)switch(_ctx.prev = _ctx.next){
                case 0:
                    _ctx.prev = 0;
                    setState(function(state) {
                        return _objectSpread({
                        }, state, {
                            loading: true
                        });
                    });
                    url = (0, _getAPIURL).default("/suggestions?q=".concat(encodeURIComponent(text.trim())));
                    _ctx.next = 5;
                    return fetch(url, {
                        credentials: 'include'
                    }).then(function(res) {
                        return res.json();
                    });
                case 5:
                    groups = _ctx.sent.groups;
                    setState(function(state) {
                        return _objectSpread({
                        }, state, {
                            loading: false,
                            groups: groups
                        });
                    });
                    _ctx.next = 12;
                    break;
                case 9:
                    _ctx.prev = 9;
                    _ctx.t0 = _ctx["catch"](0);
                    if (!_fetchLatest.StaleResponseError.is(_ctx.t0)) {
                        setState(function(state) {
                            return _objectSpread({
                            }, state, {
                                loading: false
                            });
                        });
                    }
                case 12:
                case "end":
                    return _ctx.stop();
            }
        }, _callee, null, [
            [
                0,
                9
            ]
        ]);
    }));
    (0, _react).useEffect(function() {
        if (active && (debouncedQuery.length >= minQueryLength || !debouncedQuery)) {
            fetchSuggestions(debouncedQuery);
        }
    }, [
        active,
        debouncedQuery
    ]);
    var context = {
        query: debouncedQuery,
        state: state1,
        setState: setState,
        fetchSuggestions: fetchSuggestions
    };
    return(/*#__PURE__*/ _react.default.createElement(_searchContext.default.Provider, {
        value: context
    }, children));
}
SearchProvider.propTypes = {
    open: _propTypes.default.bool,
    initialGroups: _propTypes.default.array,
    /**
   * Minimum length of search query to fetch. Default is 3
   */ minQueryLength: _propTypes.default.number,
    /**
   * Default is 250
   */ debounceTime: _propTypes.default.number,
    query: _propTypes.default.string,
    active: _propTypes.default.bool
};
SearchProvider.defaultProps = {
    minQueryLength: 3,
    debounceTime: 250
};

//# sourceMappingURL=SearchProvider.js.map