"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = listRoutes;
var _fs = _interopRequireDefault(require("fs"));
var _path = _interopRequireDefault(require("path"));
var _glob = _interopRequireDefault(require("glob"));
var _getRoutes = _interopRequireDefault(require("./getRoutes"));
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
// Depending on the context (local dev, serverless lambda), the page manifest
// file can be at different locations
var MANIFEST_PATHS = [
    _path.default.join(process.cwd(), 'pages-manifest.json'),
    _path.default.join(process.cwd(), '.next', 'server', 'pages-manifest.json'),
    _path.default.join(process.cwd(), '.next', 'serverless', 'pages-manifest.json'), 
];
function listRoutes() {
    var manifest;
    if (process.env.NODE_ENV === 'production') {
        var manifestPath = MANIFEST_PATHS.find(function(path) {
            return _fs.default.existsSync(path);
        });
        /* istanbul ignore else */ if (manifestPath) {
            manifest = JSON.parse(_fs.default.readFileSync(manifestPath, 'utf-8'));
        } else {
            throw new Error("Could not find pages-manifests.json in ".concat(MANIFEST_PATHS.join(' or ')));
        }
    } else {
        manifest = createDevelopmentPagesManifest();
    }
    return (0, _getRoutes).default(manifest);
}
/**
 * Creates the equivalent of pages-manifest.json in development.  Since
 * next.js incrementally compiles pages on demand in development, pages-manifest may
 * not have all of the pages until they are visited and thus cannot be used by useSimpleNavigation
 * reliably in development.
 */ function createDevelopmentPagesManifest() {
    var pages = _glob.default.sync('pages/**/*.js', {
        cwd: process.cwd()
    });
    var manifest = {
    };
    var _iteratorNormalCompletion = true, _didIteratorError = false, _iteratorError = undefined;
    try {
        for(var _iterator = pages[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true){
            var page = _step.value;
            var route = page.replace(/^pages/, '').replace(/\.[^/]+$/, '');
            manifest[route] = page;
        }
    } catch (err) {
        _didIteratorError = true;
        _iteratorError = err;
    } finally{
        try {
            if (!_iteratorNormalCompletion && _iterator.return != null) {
                _iterator.return();
            }
        } finally{
            if (_didIteratorError) {
                throw _iteratorError;
            }
        }
    }
    return manifest;
}

//# sourceMappingURL=listRoutes.js.map