"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.waitForServiceWorker = waitForServiceWorker;
exports.prefetch = prefetch;
exports.prefetchJsonFor = prefetchJsonFor;
exports.resetPrefetches = resetPrefetches;
var _regeneratorRuntime = _interopRequireDefault(require("regenerator-runtime"));
var _getAPIURL = _interopRequireDefault(require("./api/getAPIURL"));
var _addVersion = _interopRequireDefault(require("./api/addVersion"));
function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
    try {
        var info = gen[key](arg);
        var value = info.value;
    } catch (error) {
        reject(error);
        return;
    }
    if (info.done) {
        resolve(value);
    } else {
        Promise.resolve(value).then(_next, _throw);
    }
}
function _asyncToGenerator(fn) {
    return function() {
        var self = this, args = arguments;
        return new Promise(function(resolve, reject) {
            var gen = fn.apply(self, args);
            function _next(value) {
                asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
            }
            function _throw(err) {
                asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
            }
            _next(undefined);
        });
    };
}
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
var prefetched = new Set();
function waitForServiceWorker() {
    if (!navigator.serviceWorker || !navigator.serviceWorker.ready) {
        return false;
    }
    return new Promise(function(resolve) {
        navigator.serviceWorker.ready.then(function() {
            if (navigator.serviceWorker.controller) {
                return resolve(true);
            }
            navigator.serviceWorker.addEventListener('controllerchange', function() {
                return resolve(true);
            });
        });
    });
}
function prefetch(url) {
    return _prefetch.apply(this, arguments);
}
function _prefetch() {
    _prefetch = _asyncToGenerator(_regeneratorRuntime.default.mark(function _callee(url) {
        var link, relList, rel;
        return _regeneratorRuntime.default.wrap(function _callee$(_ctx) {
            while(1)switch(_ctx.prev = _ctx.next){
                case 0:
                    if (!(url == null)) {
                        _ctx.next = 2;
                        break;
                    }
                    return _ctx.abrupt("return");
                case 2:
                    if (!(process.env.NODE_ENV !== 'production' && process.env.SERVICE_WORKER !== 'true')) {
                        _ctx.next = 4;
                        break;
                    }
                    return _ctx.abrupt("return");
                case 4:
                    url = (0, _addVersion).default(url).toString();
                    if (!prefetched.has(url)) {
                        _ctx.next = 7;
                        break;
                    }
                    return _ctx.abrupt("return");
                case 7:
                    prefetched.add(url);
                    _ctx.next = 10;
                    return waitForServiceWorker();
                case 10:
                    link = document.createElement('link');
                    relList = link.relList;
                    rel = relList.supports('preload') && /* istanbul ignore next */ !relList.supports('prefetch') ? /* istanbul ignore next */ 'preload' : 'prefetch' // Safari does not support prefetch so we use preload instead
                    ;
                    link.setAttribute('href', addPrefetchParam(url));
                    link.setAttribute('as', 'fetch');
                    link.setAttribute('rel', rel);
                    document.head.append(link);
                case 17:
                case "end":
                    return _ctx.stop();
            }
        }, _callee);
    }));
    return _prefetch.apply(this, arguments);
}
function prefetchJsonFor(url) {
    return prefetch((0, _getAPIURL).default(url));
}
/**
 * Adds process.env.PREFETCH_QUERY_PARAM to the URL so that back ends can identify prefetch requests and
 * potentially ignore them during periods of high traffic.
 * @param {String} url
 * @return {String} A new URL
 */ function addPrefetchParam(url) {
    var prefetchQueryParam = process.env.RSF_PREFETCH_QUERY_PARAM;
    if (prefetchQueryParam) {
        var parsed = new URL(url, location.href);
        if (parsed.hostname === location.hostname) {
            // only add __prefetch__ for requests going back to Layer0.
            parsed.searchParams.append(prefetchQueryParam, '1');
        }
        return parsed.toString();
    }
    return url;
}
function resetPrefetches() {
    prefetched.clear();
}

//# sourceMappingURL=serviceWorker.js.map