"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = configureServiceWorker;
var _workboxRouting = require("workbox-routing");
var _workboxCore = require("workbox-core");
var _workboxPrecaching = require("workbox-precaching");
var _workboxStrategies = require("workbox-strategies");
var _workboxExpiration = require("workbox-expiration");
var _workboxCacheableResponse = require("workbox-cacheable-response");
function _arrayWithoutHoles(arr) {
    if (Array.isArray(arr)) {
        for(var i = 0, arr2 = new Array(arr.length); i < arr.length; i++){
            arr2[i] = arr[i];
        }
        return arr2;
    }
}
function _iterableToArray(iter) {
    if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter);
}
function _nonIterableSpread() {
    throw new TypeError("Invalid attempt to spread non-iterable instance");
}
function _toConsumableArray(arr) {
    return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread();
}
function configureServiceWorker(config) {
    (0, _workboxCore).skipWaiting();
    (0, _workboxCore).clientsClaim();
    (0, _workboxPrecaching).precacheAndRoute(self.__WB_MANIFEST || []);
    if (config.api) {
        cacheAPIRequests(config.api);
    }
}
/**
 * Creates worbox routes for api routes
 * @param {Object[]} api
 */ function cacheAPIRequests(api) {
    var _iteratorNormalCompletion = true, _didIteratorError = false, _iteratorError = undefined;
    try {
        for(var _iterator = api[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true){
            var _value = _step.value, path = _value.path, maxAgeSeconds = _value.maxAgeSeconds, _statuses = _value.statuses, statuses = _statuses === void 0 ? [
                200
            ] : _statuses;
            var url = new RegExp("".concat(self.origin).concat(nextRouteToRegex(path)), 'i');
            log('Caching API route', path, url);
            (0, _workboxRouting).registerRoute(url, new _workboxStrategies.CacheFirst({
                cacheName: 'api',
                plugins: [
                    new _workboxCacheableResponse.CacheableResponsePlugin({
                        statuses: statuses
                    }),
                    new _workboxExpiration.ExpirationPlugin({
                        maxAgeSeconds: maxAgeSeconds
                    }), 
                ]
            }));
        }
    } catch (err) {
        _didIteratorError = true;
        _iteratorError = err;
    } finally{
        try {
            if (!_iteratorNormalCompletion && _iterator.return != null) {
                _iterator.return();
            }
        } finally{
            if (_didIteratorError) {
                throw _iteratorError;
            }
        }
    }
}
/**
 * Converts next clean route syntax to a regular expression
 * @param {String} route A next.js route pattern
 * @return {String}
 */ function nextRouteToRegex(route) {
    return "".concat(route.replace(/\[[^\]]+\]/gi, '[^/]+'), "($|\\?.*$)");
}
/**
 * Stylized console.log
 * @param  {...any} message
 */ function log() {
    for(var _len = arguments.length, message = new Array(_len), _key = 0; _key < _len; _key++){
        message[_key] = arguments[_key];
    }
    // istanbul ignore else
    if (process.env.NODE_ENV !== 'production') {
        var _console;
        (_console = console).log.apply(_console, [
            '%creact-storefront service-worker',
            'background: #43a047; color: #ffffff; font-weight:bold; padding: 3px 5px; border-radius: 5px', 
        ].concat(_toConsumableArray(message)));
    }
}

//# sourceMappingURL=configureServiceWorker.js.map