"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = lazyLoadImages;
function _arrayWithoutHoles(arr) {
    if (Array.isArray(arr)) {
        for(var i = 0, arr2 = new Array(arr.length); i < arr.length; i++){
            arr2[i] = arr[i];
        }
        return arr2;
    }
}
function _iterableToArray(iter) {
    if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter);
}
function _nonIterableSpread() {
    throw new TypeError("Invalid attempt to spread non-iterable instance");
}
function _toConsumableArray(arr) {
    return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread();
}
function lazyLoadImages(element) {
    var ref = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {
    }, _lazySrcAttribute = ref.lazySrcAttribute, lazySrcAttribute = _lazySrcAttribute === void 0 ? 'data-src' : _lazySrcAttribute;
    if (!element) return;
    var lazyImages = _toConsumableArray(element.querySelectorAll("img[".concat(lazySrcAttribute, "]")));
    if (!lazyImages.length) return;
    var lazyImageObserver;
    var load = function(img) {
        var src = img.getAttribute(lazySrcAttribute);
        var onload = function() {
            img.removeAttribute(lazySrcAttribute);
            img.removeEventListener('load', onload);
        };
        img.addEventListener('load', onload);
        img.setAttribute('src', src);
    };
    var observerHandler = function observerHandler(entries, self) {
        var _iteratorNormalCompletion = true, _didIteratorError = false, _iteratorError = undefined;
        try {
            for(var _iterator = entries[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true){
                var entry = _step.value;
                if (entry.isIntersecting) {
                    load(entry.target);
                    // the image is now in place, stop watching
                    if (self) {
                        self.unobserve(entry.target);
                    }
                }
            }
        } catch (err) {
            _didIteratorError = true;
            _iteratorError = err;
        } finally{
            try {
                if (!_iteratorNormalCompletion && _iterator.return != null) {
                    _iterator.return();
                }
            } finally{
                if (_didIteratorError) {
                    throw _iteratorError;
                }
            }
        }
    };
    try {
        lazyImageObserver = new window.IntersectionObserver(observerHandler);
        var _iteratorNormalCompletion2 = true, _didIteratorError2 = false, _iteratorError2 = undefined;
        try {
            for(var _iterator2 = lazyImages[Symbol.iterator](), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true){
                var img2 = _step2.value;
                lazyImageObserver.observe(img2);
            }
        } catch (err) {
            _didIteratorError2 = true;
            _iteratorError2 = err;
        } finally{
            try {
                if (!_iteratorNormalCompletion2 && _iterator2.return != null) {
                    _iterator2.return();
                }
            } finally{
                if (_didIteratorError2) {
                    throw _iteratorError2;
                }
            }
        }
        return lazyImageObserver;
    } catch (e) {
        var _iteratorNormalCompletion1 = true, _didIteratorError1 = false, _iteratorError1 = undefined;
        try {
            // eagerly load images when we don't have the observer
            for(var _iterator1 = lazyImages[Symbol.iterator](), _step1; !(_iteratorNormalCompletion1 = (_step1 = _iterator1.next()).done); _iteratorNormalCompletion1 = true){
                var img1 = _step1.value;
                load(img1);
            }
        } catch (err) {
            _didIteratorError1 = true;
            _iteratorError1 = err;
        } finally{
            try {
                if (!_iteratorNormalCompletion1 && _iterator1.return != null) {
                    _iterator1.return();
                }
            } finally{
                if (_didIteratorError1) {
                    throw _iteratorError1;
                }
            }
        }
    }
}

//# sourceMappingURL=lazyLoadImages.js.map